<?php
/**
 * Enhanced Bet Analyzer Class
 * Path: classes/BetAnalyzer.php
 */

class BetAnalyzer {
    private $footballAPI;
    
    /**
     * Constructor
     */
    public function __construct() {
        $this->footballAPI = new FootballAPI();
    }
    
    /**
     * Analyze match and provide enhanced betting recommendations
     * @param int $homeTeamId
     * @param int $awayTeamId
     * @return array
     */
    public function analyzeMatch($homeTeamId, $awayTeamId) {
        // Get team data
        $homeTeam = $this->footballAPI->getTeam($homeTeamId);
        $awayTeam = $this->footballAPI->getTeam($awayTeamId);
        
        // Get recent matches
        $homeTeamMatches = $this->footballAPI->getTeamMatches($homeTeamId, 10);
        $awayTeamMatches = $this->footballAPI->getTeamMatches($awayTeamId, 10);
        
        // Get head-to-head matches
        $h2hMatches = $this->footballAPI->getHeadToHead($homeTeamId, $awayTeamId, 5);
        
        // Calculate team stats
        $homeTeamStats = $this->calculateTeamStats($homeTeamMatches, $homeTeamId);
        $awayTeamStats = $this->calculateTeamStats($awayTeamMatches, $awayTeamId);
        
        // Analyze head-to-head
        $h2hAnalysis = $this->analyzeHeadToHead($h2hMatches, $homeTeamId, $awayTeamId);
        
        // Generate betting recommendations
        $recommendations = $this->generateRecommendations(
            $homeTeamStats,
            $awayTeamStats,
            $h2hAnalysis,
            $homeTeam,
            $awayTeam
        );
        
        // Return complete analysis
        return [
            'homeTeam' => [
                'info' => $homeTeam,
                'stats' => $homeTeamStats
            ],
            'awayTeam' => [
                'info' => $awayTeam,
                'stats' => $awayTeamStats
            ],
            'headToHead' => $h2hAnalysis,
            'recommendations' => $recommendations
        ];
    }
    
    /**
     * Calculate team statistics
     * @param array $matches
     * @param int $teamId
     * @return array
     */
    private function calculateTeamStats($matches, $teamId) {
        $stats = [
            'played' => 0,
            'wins' => 0,
            'draws' => 0,
            'losses' => 0,
            'goalsFor' => 0,
            'goalsAgainst' => 0,
            'cleanSheets' => 0,
            'failedToScore' => 0,
            'bttsCount' => 0,
            'over2_5Count' => 0,
            'over1_5Count' => 0,
            'cornersFor' => 0,
            'cornersAgainst' => 0,
            'scoredFirst' => 0,
            'concededFirst' => 0,
            'form' => [],
            'goalDistribution' => [0 => 0, 1 => 0, 2 => 0, 3 => 0, '4+' => 0]
        ];
        
        if (empty($matches)) {
            return $stats;
        }
        
        foreach ($matches as $match) {
            if ($match['status'] !== 'FINISHED') {
                continue;
            }
            
            $stats['played']++;
            
            $isHome = $match['homeTeam']['id'] == $teamId;
            $homeGoals = $match['score']['fullTime']['home'] ?? 0;
            $awayGoals = $match['score']['fullTime']['away'] ?? 0;
            
            $teamGoals = $isHome ? $homeGoals : $awayGoals;
            $opponentGoals = $isHome ? $awayGoals : $homeGoals;
            
            // Add goals
            $stats['goalsFor'] += $teamGoals;
            $stats['goalsAgainst'] += $opponentGoals;
            
            // Goal distribution
            if ($teamGoals >= 4) {
                $stats['goalDistribution']['4+']++;
            } else {
                $stats['goalDistribution'][$teamGoals]++;
            }
            
            // Clean sheets and failed to score
            if ($opponentGoals == 0) $stats['cleanSheets']++;
            if ($teamGoals == 0) $stats['failedToScore']++;
            
            // Both teams to score
            if ($teamGoals > 0 && $opponentGoals > 0) $stats['bttsCount']++;
            
            // Over/Under goals
            $totalGoals = $homeGoals + $awayGoals;
            if ($totalGoals > 2.5) $stats['over2_5Count']++;
            if ($totalGoals > 1.5) $stats['over1_5Count']++;
            
            // Corner stats (if available)
            if (isset($match['stats'])) {
                foreach ($match['stats'] as $stat) {
                    if ($stat['type'] == 'CORNER_KICK') {
                        if ($isHome) {
                            $stats['cornersFor'] += ($stat['home'] ?? 0);
                            $stats['cornersAgainst'] += ($stat['away'] ?? 0);
                        } else {
                            $stats['cornersFor'] += ($stat['away'] ?? 0);
                            $stats['cornersAgainst'] += ($stat['home'] ?? 0);
                        }
                    }
                }
            }
            
            // First team to score (if goal data available)
            if (isset($match['goals']) && !empty($match['goals'])) {
                $firstGoal = $match['goals'][0];
                $scoredByTeam = $firstGoal['team']['id'] == $teamId;
                
                if ($scoredByTeam) {
                    $stats['scoredFirst']++;
                } else {
                    $stats['concededFirst']++;
                }
            }
            
            // Match result
            if ($isHome) {
                if ($homeGoals > $awayGoals) $stats['wins']++;
                elseif ($homeGoals == $awayGoals) $stats['draws']++;
                else $stats['losses']++;
            } else {
                if ($awayGoals > $homeGoals) $stats['wins']++;
                elseif ($awayGoals == $homeGoals) $stats['draws']++;
                else $stats['losses']++;
            }
            
            // Form (last 5 matches)
            if (count($stats['form']) < 5) {
                if ($isHome) {
                    if ($homeGoals > $awayGoals) $stats['form'][] = 'W';
                    elseif ($homeGoals == $awayGoals) $stats['form'][] = 'D';
                    else $stats['form'][] = 'L';
                } else {
                    if ($awayGoals > $homeGoals) $stats['form'][] = 'W';
                    elseif ($awayGoals == $homeGoals) $stats['form'][] = 'D';
                    else $stats['form'][] = 'L';
                }
            }
        }
        
        // Calculate averages and percentages
        if ($stats['played'] > 0) {
            $stats['winRate'] = round(($stats['wins'] / $stats['played']) * 100, 1);
            $stats['drawRate'] = round(($stats['draws'] / $stats['played']) * 100, 1);
            $stats['lossRate'] = round(($stats['losses'] / $stats['played']) * 100, 1);
            $stats['avgGoalsFor'] = round($stats['goalsFor'] / $stats['played'], 2);
            $stats['avgGoalsAgainst'] = round($stats['goalsAgainst'] / $stats['played'], 2);
            $stats['cleanSheetRate'] = round(($stats['cleanSheets'] / $stats['played']) * 100, 1);
            $stats['failedToScoreRate'] = round(($stats['failedToScore'] / $stats['played']) * 100, 1);
            $stats['bttsRate'] = round(($stats['bttsCount'] / $stats['played']) * 100, 1);
            $stats['over2_5Rate'] = round(($stats['over2_5Count'] / $stats['played']) * 100, 1);
            $stats['over1_5Rate'] = round(($stats['over1_5Count'] / $stats['played']) * 100, 1);
            $stats['avgCornersFor'] = $stats['cornersFor'] > 0 ? round($stats['cornersFor'] / $stats['played'], 2) : 0;
            $stats['avgCornersAgainst'] = $stats['cornersAgainst'] > 0 ? round($stats['cornersAgainst'] / $stats['played'], 2) : 0;
            $stats['scoredFirstRate'] = $stats['scoredFirst'] > 0 ? round(($stats['scoredFirst'] / $stats['played']) * 100, 1) : 0;
            
            // Calculate goal distribution percentages
            foreach ($stats['goalDistribution'] as $goals => $count) {
                $stats['goalDistribution'][$goals] = [
                    'count' => $count,
                    'percentage' => round(($count / $stats['played']) * 100, 1)
                ];
            }
        }
        
        return $stats;
    }
    
    /**
     * Analyze head-to-head matches
     * @param array $matches
     * @param int $homeTeamId
     * @param int $awayTeamId
     * @return array
     */
    private function analyzeHeadToHead($matches, $homeTeamId, $awayTeamId) {
        $h2h = [
            'played' => 0,
            'homeTeamWins' => 0,
            'draws' => 0,
            'awayTeamWins' => 0,
            'totalGoals' => 0,
            'bttsCount' => 0,
            'over2_5Count' => 0,
            'over1_5Count' => 0,
            'homeTeamGoals' => 0,
            'awayTeamGoals' => 0,
            'homeTeamScoredFirst' => 0,
            'totalCorners' => 0,
            'avgCornersPerMatch' => 0,
            'matches' => []
        ];
        
        if (empty($matches)) {
            return $h2h;
        }
        
        foreach ($matches as $match) {
            if ($match['status'] !== 'FINISHED') {
                continue;
            }
            
            $h2h['played']++;
            
            $homeGoals = $match['score']['fullTime']['home'] ?? 0;
            $awayGoals = $match['score']['fullTime']['away'] ?? 0;
            $matchHomeTeamId = $match['homeTeam']['id'];
            $matchAwayTeamId = $match['awayTeam']['id'];
            
            // Total goals
            $totalGoals = $homeGoals + $awayGoals;
            $h2h['totalGoals'] += $totalGoals;
            
            // Goals by each team in H2H
            if ($matchHomeTeamId == $homeTeamId) {
                $h2h['homeTeamGoals'] += $homeGoals;
                $h2h['awayTeamGoals'] += $awayGoals;
            } else {
                $h2h['homeTeamGoals'] += $awayGoals;
                $h2h['awayTeamGoals'] += $homeGoals;
            }
            
            // Both teams to score
            if ($homeGoals > 0 && $awayGoals > 0) {
                $h2h['bttsCount']++;
            }
            
            // Over goals
            if ($totalGoals > 2.5) {
                $h2h['over2_5Count']++;
            }
            if ($totalGoals > 1.5) {
                $h2h['over1_5Count']++;
            }
            
            // First team to score (if goal data available)
            if (isset($match['goals']) && !empty($match['goals'])) {
                $firstGoal = $match['goals'][0];
                if ($firstGoal['team']['id'] == $homeTeamId) {
                    $h2h['homeTeamScoredFirst']++;
                }
            }
            
            // Corner stats (if available)
            if (isset($match['stats'])) {
                foreach ($match['stats'] as $stat) {
                    if ($stat['type'] == 'CORNER_KICK') {
                        $totalCorners = ($stat['home'] ?? 0) + ($stat['away'] ?? 0);
                        $h2h['totalCorners'] += $totalCorners;
                    }
                }
            }
            
            // Match result
            if ($homeGoals > $awayGoals) {
                if ($matchHomeTeamId == $homeTeamId) {
                    $h2h['homeTeamWins']++;
                } else {
                    $h2h['awayTeamWins']++;
                }
            } elseif ($homeGoals < $awayGoals) {
                if ($matchAwayTeamId == $homeTeamId) {
                    $h2h['homeTeamWins']++;
                } else {
                    $h2h['awayTeamWins']++;
                }
            } else {
                $h2h['draws']++;
            }
            
            // Add match details
            $h2h['matches'][] = [
                'id' => $match['id'],
                'date' => $match['utcDate'],
                'homeTeamId' => $matchHomeTeamId,
                'awayTeamId' => $matchAwayTeamId,
                'homeGoals' => $homeGoals,
                'awayGoals' => $awayGoals,
                'score' => $homeGoals . '-' . $awayGoals,
                'winner' => $homeGoals > $awayGoals ? $matchHomeTeamId : ($awayGoals > $homeGoals ? $matchAwayTeamId : 'draw')
            ];
        }
        
        // Calculate percentages and averages
        if ($h2h['played'] > 0) {
            $h2h['homeTeamWinRate'] = round(($h2h['homeTeamWins'] / $h2h['played']) * 100, 1);
            $h2h['drawRate'] = round(($h2h['draws'] / $h2h['played']) * 100, 1);
            $h2h['awayTeamWinRate'] = round(($h2h['awayTeamWins'] / $h2h['played']) * 100, 1);
            $h2h['avgGoalsPerMatch'] = round($h2h['totalGoals'] / $h2h['played'], 2);
            $h2h['avgHomeTeamGoals'] = round($h2h['homeTeamGoals'] / $h2h['played'], 2);
            $h2h['avgAwayTeamGoals'] = round($h2h['awayTeamGoals'] / $h2h['played'], 2);
            $h2h['bttsRate'] = round(($h2h['bttsCount'] / $h2h['played']) * 100, 1);
            $h2h['over2_5Rate'] = round(($h2h['over2_5Count'] / $h2h['played']) * 100, 1);
            $h2h['over1_5Rate'] = round(($h2h['over1_5Count'] / $h2h['played']) * 100, 1);
            $h2h['homeTeamScoredFirstRate'] = round(($h2h['homeTeamScoredFirst'] / $h2h['played']) * 100, 1);
            $h2h['avgCornersPerMatch'] = $h2h['totalCorners'] > 0 ? round($h2h['totalCorners'] / $h2h['played'], 2) : 0;
        }
        
        return $h2h;
    }
    
    /**
     * Generate enhanced betting recommendations
     * @param array $homeTeamStats
     * @param array $awayTeamStats
     * @param array $h2hAnalysis
     * @param array $homeTeam
     * @param array $awayTeam
     * @return array
     */
    private function generateRecommendations($homeTeamStats, $awayTeamStats, $h2hAnalysis, $homeTeam, $awayTeam) {
        $recommendations = [
            'matchOutcome' => [],
            'btts' => [],
            'over_under' => [],
            'over1_5' => [],
            'corners' => [],
            'teamGoals' => [
                'home' => [],
                'away' => []
            ],
            'firstToScore' => [],
            'safeBets' => [],
            'reasoning' => []
        ];
        
        // Home advantage factor (typically around 60% for most leagues)
        $homeAdvantage = 1.2;
        
        // Match outcome probabilities
        $homeWinProb = $this->calculateHomeWinProbability($homeTeamStats, $awayTeamStats, $h2hAnalysis, $homeAdvantage);
        $drawProb = $this->calculateDrawProbability($homeTeamStats, $awayTeamStats, $h2hAnalysis);
        $awayWinProb = $this->calculateAwayWinProbability($homeTeamStats, $awayTeamStats, $h2hAnalysis);
        
        // Normalize to 100%
        $total = $homeWinProb + $drawProb + $awayWinProb;
        $homeWinProb = round(($homeWinProb / $total) * 100, 1);
        $drawProb = round(($drawProb / $total) * 100, 1);
        $awayWinProb = round(($awayWinProb / $total) * 100, 1);
        
        $matchOutcomeSuggestion = $this->getHighestProbability([
            'Home Win' => $homeWinProb,
            'Draw' => $drawProb,
            'Away Win' => $awayWinProb
        ]);
        
        $recommendations['matchOutcome'] = [
            'homeWin' => $homeWinProb,
            'draw' => $drawProb,
            'awayWin' => $awayWinProb,
            'suggested' => $matchOutcomeSuggestion,
            'confidence' => $this->getConfidenceLevel(max($homeWinProb, $drawProb, $awayWinProb))
        ];
        
        // Add reasoning for match outcome
        $recommendations['reasoning']['matchOutcome'] = $this->getMatchOutcomeReasoning(
            $homeTeamStats, 
            $awayTeamStats, 
            $h2hAnalysis, 
            $homeTeam['name'], 
            $awayTeam['name'],
            $matchOutcomeSuggestion
        );
        
        // Both teams to score
        $bttsYesProb = $this->calculateBttsYesProbability($homeTeamStats, $awayTeamStats, $h2hAnalysis);
        $bttsNoProb = 100 - $bttsYesProb;
        
        $bttsSuggestion = $bttsYesProb > $bttsNoProb ? 'Yes' : 'No';
        
        $recommendations['btts'] = [
            'yes' => $bttsYesProb,
            'no' => $bttsNoProb,
            'suggested' => $bttsSuggestion,
            'confidence' => $this->getConfidenceLevel(max($bttsYesProb, $bttsNoProb))
        ];
        
        // Add reasoning for BTTS
        $recommendations['reasoning']['btts'] = $this->getBttsReasoning(
            $homeTeamStats, 
            $awayTeamStats, 
            $h2hAnalysis, 
            $homeTeam['name'], 
            $awayTeam['name'],
            $bttsSuggestion
        );
        
        // Over/Under 2.5 goals
        $over2_5Prob = $this->calculateOver2_5Probability($homeTeamStats, $awayTeamStats, $h2hAnalysis);
        $under2_5Prob = 100 - $over2_5Prob;
        
        $over2_5Suggestion = $over2_5Prob > $under2_5Prob ? 'Over 2.5' : 'Under 2.5';
        
        $recommendations['over_under'] = [
            'over2_5' => $over2_5Prob,
            'under2_5' => $under2_5Prob,
            'suggested' => $over2_5Suggestion,
            'confidence' => $this->getConfidenceLevel(max($over2_5Prob, $under2_5Prob))
        ];
        
        // Add reasoning for Over/Under 2.5
        $recommendations['reasoning']['over_under'] = $this->getOverUnderReasoning(
            $homeTeamStats, 
            $awayTeamStats, 
            $h2hAnalysis, 
            $homeTeam['name'], 
            $awayTeam['name'],
            $over2_5Suggestion
        );
        
        // Over/Under 1.5 goals
        $over1_5Prob = $this->calculateOver1_5Probability($homeTeamStats, $awayTeamStats, $h2hAnalysis);
        $under1_5Prob = 100 - $over1_5Prob;
        
        $over1_5Suggestion = $over1_5Prob > $under1_5Prob ? 'Over 1.5' : 'Under 1.5';
        
        $recommendations['over1_5'] = [
            'over1_5' => $over1_5Prob,
            'under1_5' => $under1_5Prob,
            'suggested' => $over1_5Suggestion,
            'confidence' => $this->getConfidenceLevel(max($over1_5Prob, $under1_5Prob))
        ];
        
        // Add reasoning for Over/Under 1.5
        $recommendations['reasoning']['over1_5'] = $this->getOver1_5Reasoning(
            $homeTeamStats, 
            $awayTeamStats, 
            $h2hAnalysis, 
            $homeTeam['name'], 
            $awayTeam['name'],
            $over1_5Suggestion
        );
        
        // Corner market
        $totalCornersProb = $this->calculateTotalCorners($homeTeamStats, $awayTeamStats, $h2hAnalysis);
        
        $recommendations['corners'] = [
            'expectedTotal' => round($totalCornersProb['expected'], 1),
            'over8_5' => $totalCornersProb['over8_5'],
            'over9_5' => $totalCornersProb['over9_5'],
            'over10_5' => $totalCornersProb['over10_5'],
            'suggested' => $totalCornersProb['suggested'],
            'confidence' => $totalCornersProb['confidence']
        ];
        
        // Add reasoning for corners
        $recommendations['reasoning']['corners'] = $this->getCornersReasoning(
            $homeTeamStats, 
            $awayTeamStats, 
            $h2hAnalysis, 
            $homeTeam['name'], 
            $awayTeam['name'],
            $totalCornersProb['suggested']
        );
        
        // Team goals
        $homeTeamGoalsProb = $this->calculateTeamGoals($homeTeamStats, $awayTeamStats, $h2hAnalysis, true);
        $awayTeamGoalsProb = $this->calculateTeamGoals($homeTeamStats, $awayTeamStats, $h2hAnalysis, false);
        
        $recommendations['teamGoals']['home'] = [
            'expectedGoals' => round($homeTeamGoalsProb['expected'], 2),
            'over0_5' => $homeTeamGoalsProb['over0_5'],
            'over1_5' => $homeTeamGoalsProb['over1_5'],
            'over2_5' => $homeTeamGoalsProb['over2_5'],
            'suggested' => $homeTeamGoalsProb['suggested'],
            'mostLikelyCount' => $homeTeamGoalsProb['mostLikely'],
            'confidence' => $homeTeamGoalsProb['confidence']
        ];
        
        $recommendations['teamGoals']['away'] = [
            'expectedGoals' => round($awayTeamGoalsProb['expected'], 2),
            'over0_5' => $awayTeamGoalsProb['over0_5'],
            'over1_5' => $awayTeamGoalsProb['over1_5'],
            'over2_5' => $awayTeamGoalsProb['over2_5'],
            'suggested' => $awayTeamGoalsProb['suggested'],
            'mostLikelyCount' => $awayTeamGoalsProb['mostLikely'],
            'confidence' => $awayTeamGoalsProb['confidence']
        ];
        
        // Add reasoning for team goals
        $recommendations['reasoning']['teamGoals'] = $this->getTeamGoalsReasoning(
            $homeTeamStats, 
            $awayTeamStats, 
            $h2hAnalysis, 
            $homeTeam['name'], 
            $awayTeam['name'],
            $homeTeamGoalsProb,
            $awayTeamGoalsProb
        );
        
        // First to score
        $firstToScoreProb = $this->calculateFirstToScore($homeTeamStats, $awayTeamStats, $h2hAnalysis);
        
        $recommendations['firstToScore'] = [
            'home' => $firstToScoreProb['home'],
            'away' => $firstToScoreProb['away'],
            'noGoal' => $firstToScoreProb['noGoal'],
            'suggested' => $firstToScoreProb['suggested'],
            'confidence' => $firstToScoreProb['confidence']
        ];
        
        // Add reasoning for first to score
        $recommendations['reasoning']['firstToScore'] = $this->getFirstToScoreReasoning(
            $homeTeamStats, 
            $awayTeamStats, 
            $h2hAnalysis, 
            $homeTeam['name'], 
            $awayTeam['name'],
            $firstToScoreProb['suggested']
        );
        
        // Safe bets - bets with high confidence
        $recommendations['safeBets'] = $this->identifySafeBets(
            $recommendations['matchOutcome'],
            $recommendations['btts'],
            $recommendations['over_under'],
            $recommendations['over1_5'],
            $recommendations['corners'],
            $recommendations['teamGoals'],
            $recommendations['firstToScore']
        );
        
        return $recommendations;
    }
    
    /**
     * Calculate home win probability
     */
    private function calculateHomeWinProbability($homeTeamStats, $awayTeamStats, $h2hAnalysis, $homeAdvantage) {
        $probability = 0;
        
        // Team strength factors
        $probability += ($homeTeamStats['winRate'] ?? 0) * 0.25;
        $probability += ((100 - ($awayTeamStats['winRate'] ?? 0)) * 0.2);
        
        // Goal-related factors
        $probability += ($homeTeamStats['avgGoalsFor'] ?? 0) * 5;
        $probability -= ($awayTeamStats['avgGoalsFor'] ?? 0) * 3;
        
        // Head-to-head factor
        if (isset($h2hAnalysis['homeTeamWinRate'])) {
            $probability += $h2hAnalysis['homeTeamWinRate'] * 0.2;
        }
        
        // Form factor
        $homeForm = $this->getFormPoints($homeTeamStats['form'] ?? []);
        $awayForm = $this->getFormPoints($awayTeamStats['form'] ?? []);
        $probability += ($homeForm - $awayForm) * 2;
        
        // Apply home advantage
        $probability *= $homeAdvantage;
        
        return max(0, $probability);
    }
    
    /**
     * Calculate draw probability
     */
    private function calculateDrawProbability($homeTeamStats, $awayTeamStats, $h2hAnalysis) {
        $probability = 25; // Base probability
        
        // Team strength similarity increases draw probability
        $winRateDiff = abs(($homeTeamStats['winRate'] ?? 0) - ($awayTeamStats['winRate'] ?? 0));
        $probability += (40 - $winRateDiff) * 0.5; // More similar teams = higher draw chance
        
        // Goal-related factors
        $probability += (($homeTeamStats['avgGoalsAgainst'] ?? 0) - ($homeTeamStats['avgGoalsFor'] ?? 0)) * 2;
        $probability += (($awayTeamStats['avgGoalsAgainst'] ?? 0) - ($awayTeamStats['avgGoalsFor'] ?? 0)) * 2;
        
        // Head-to-head factor
        if (isset($h2hAnalysis['drawRate'])) {
            $probability += $h2hAnalysis['drawRate'] * 0.3;
        }
        
        return max(0, $probability);
    }
    
    /**
     * Calculate away win probability
     */
    private function calculateAwayWinProbability($homeTeamStats, $awayTeamStats, $h2hAnalysis) {
        $probability = 0;
        
        // Team strength factors
        $probability += ($awayTeamStats['winRate'] ?? 0) * 0.2;
        $probability += ((100 - ($homeTeamStats['winRate'] ?? 0)) * 0.15);
        
        // Goal-related factors
        $probability += ($awayTeamStats['avgGoalsFor'] ?? 0) * 4;
        $probability -= ($homeTeamStats['avgGoalsFor'] ?? 0) * 2;
        
        // Head-to-head factor
        if (isset($h2hAnalysis['awayTeamWinRate'])) {
            $probability += $h2hAnalysis['awayTeamWinRate'] * 0.2;
        }
        
        // Form factor
        $homeForm = $this->getFormPoints($homeTeamStats['form'] ?? []);
        $awayForm = $this->getFormPoints($awayTeamStats['form'] ?? []);
        $probability += ($awayForm - $homeForm) * 2;
        
        return max(0, $probability);
    }
    
    /**
     * Calculate BTTS Yes probability
     */
    private function calculateBttsYesProbability($homeTeamStats, $awayTeamStats, $h2hAnalysis) {
        $probability = 0;
        
        // Team scoring/conceding factors
        $probability += (($homeTeamStats['bttsRate'] ?? 0) * 0.3);
        $probability += (($awayTeamStats['bttsRate'] ?? 0) * 0.3);
        
        // Team scoring abilities
        $probability += ((100 - ($homeTeamStats['failedToScoreRate'] ?? 0)) * 0.1);
        $probability += ((100 - ($awayTeamStats['failedToScoreRate'] ?? 0)) * 0.1);
        
        // Team defensive frailties
        $probability += ((100 - ($homeTeamStats['cleanSheetRate'] ?? 0)) * 0.1);
        $probability += ((100 - ($awayTeamStats['cleanSheetRate'] ?? 0)) * 0.1);
        
        // Head-to-head factor
        if (isset($h2hAnalysis['bttsRate'])) {
            $probability += ($h2hAnalysis['bttsRate'] * 0.2);
        }
        
        return min(100, max(0, $probability));
    }
    
    /**
     * Calculate Over 2.5 probability
     */
    private function calculateOver2_5Probability($homeTeamStats, $awayTeamStats, $h2hAnalysis) {
        $probability = 0;
        
        // Team over rates
        $probability += (($homeTeamStats['over2_5Rate'] ?? 0) * 0.3);
        $probability += (($awayTeamStats['over2_5Rate'] ?? 0) * 0.3);
        
        // Average goals
        $avgTotalGoals = (($homeTeamStats['avgGoalsFor'] ?? 0) + ($homeTeamStats['avgGoalsAgainst'] ?? 0) + 
                        ($awayTeamStats['avgGoalsFor'] ?? 0) + ($awayTeamStats['avgGoalsAgainst'] ?? 0)) / 2;
        $probability += ($avgTotalGoals * 10);
        
        // Head-to-head factor
        if (isset($h2hAnalysis['over2_5Rate'])) {
            $probability += ($h2hAnalysis['over2_5Rate'] * 0.2);
        }
        
        return min(100, max(0, $probability));
    }
    
    /**
     * Calculate Over 1.5 probability
     */
    private function calculateOver1_5Probability($homeTeamStats, $awayTeamStats, $h2hAnalysis) {
        $probability = 0;
        
        // Team over rates
        $probability += (($homeTeamStats['over1_5Rate'] ?? 0) * 0.3);
        $probability += (($awayTeamStats['over1_5Rate'] ?? 0) * 0.3);
        
        // Average goals
        $avgTotalGoals = (($homeTeamStats['avgGoalsFor'] ?? 0) + ($homeTeamStats['avgGoalsAgainst'] ?? 0) + 
                        ($awayTeamStats['avgGoalsFor'] ?? 0) + ($awayTeamStats['avgGoalsAgainst'] ?? 0)) / 2;
        
        // Over 1.5 is more likely as average goals increase
        if ($avgTotalGoals > 3) {
            $probability += 25;
        } elseif ($avgTotalGoals > 2) {
            $probability += 20;
        } elseif ($avgTotalGoals > 1) {
            $probability += 15;
        }
        
        // Head-to-head factor
        if (isset($h2hAnalysis['over1_5Rate'])) {
            $probability += ($h2hAnalysis['over1_5Rate'] * 0.2);
        }
        
        // Teams that rarely fail to score
        $probability += ((100 - ($homeTeamStats['failedToScoreRate'] ?? 0)) * 0.1);
        $probability += ((100 - ($awayTeamStats['failedToScoreRate'] ?? 0)) * 0.1);
        
        return min(100, max(0, $probability));
    }
    
    /**
     * Calculate total corners
     */
    private function calculateTotalCorners($homeTeamStats, $awayTeamStats, $h2hAnalysis) {
        // Expected corners calculation
        $homeTeamCorners = ($homeTeamStats['avgCornersFor'] ?? 4.5);
        $awayTeamCorners = ($awayTeamStats['avgCornersFor'] ?? 3.5);
        $h2hCorners = ($h2hAnalysis['avgCornersPerMatch'] ?? 9);
        
        // Weighted average of team corners and H2H corners
        $expectedCorners = ($homeTeamCorners + $awayTeamCorners) * 0.6 + $h2hCorners * 0.4;
        
        // Calculate probabilities for different thresholds
        $over8_5 = $this->calculateCornerProbability($expectedCorners, 8.5);
        $over9_5 = $this->calculateCornerProbability($expectedCorners, 9.5);
        $over10_5 = $this->calculateCornerProbability($expectedCorners, 10.5);
        
        // Suggested bet based on highest probability
        $suggested = '';
        $confidence = '';
        
        if ($over8_5 > 70) {
            $suggested = 'Over 8.5 Corners';
            $confidence = $this->getConfidenceLevel($over8_5);
        } elseif ($over9_5 > 60) {
            $suggested = 'Over 9.5 Corners';
            $confidence = $this->getConfidenceLevel($over9_5);
        } elseif ($over10_5 > 50) {
            $suggested = 'Over 10.5 Corners';
            $confidence = $this->getConfidenceLevel($over10_5);
        } else {
            $suggested = 'Under 8.5 Corners';
            $confidence = $this->getConfidenceLevel(100 - $over8_5);
        }
        
        return [
            'expected' => $expectedCorners,
            'over8_5' => $over8_5,
            'over9_5' => $over9_5,
            'over10_5' => $over10_5,
            'suggested' => $suggested,
            'confidence' => $confidence
        ];
    }
    
    /**
     * Calculate corner probability based on expected corners
     */
    private function calculateCornerProbability($expectedCorners, $threshold) {
        // Poisson distribution for corner probabilities
        $probability = 0;
        
        // Calculate probability for each possible value above threshold
        for ($corners = ceil($threshold); $corners <= 20; $corners++) {
            $probability += $this->poissonProbability($corners, $expectedCorners);
        }
        
        return round($probability * 100, 1);
    }
    
    /**
     * Calculate Poisson probability
     */
    private function poissonProbability($k, $lambda) {
        return exp(-$lambda) * pow($lambda, $k) / $this->factorial($k);
    }
    
    /**
     * Calculate factorial
     */
    private function factorial($n) {
        if ($n <= 1) return 1;
        return $n * $this->factorial($n - 1);
    }
    
    /**
     * Calculate team goals probability
     */
    private function calculateTeamGoals($homeTeamStats, $awayTeamStats, $h2hAnalysis, $isHomeTeam) {
        // Get the right stats
        $teamStats = $isHomeTeam ? $homeTeamStats : $awayTeamStats;
        $opponentStats = $isHomeTeam ? $awayTeamStats : $homeTeamStats;
        
        // Base expected goals
        $avgGoalsScored = $teamStats['avgGoalsFor'] ?? 1.2;
        $avgGoalsConceded = $opponentStats['avgGoalsAgainst'] ?? 1.2;
        
        // Expected goals calculation
        $expectedGoals = ($avgGoalsScored * 0.6) + ($avgGoalsConceded * 0.4);
        
        // Adjust based on H2H if available
        if (isset($h2hAnalysis['played']) && $h2hAnalysis['played'] > 0) {
            $h2hAvgGoals = $isHomeTeam ? 
                            ($h2hAnalysis['avgHomeTeamGoals'] ?? $expectedGoals) : 
                            ($h2hAnalysis['avgAwayTeamGoals'] ?? $expectedGoals);
            
            // Blend expected goals with H2H history
            $expectedGoals = ($expectedGoals * 0.7) + ($h2hAvgGoals * 0.3);
        }
        
        // Calculate probabilities for different goal counts
        $goalProbabilities = [];
        for ($goals = 0; $goals <= 4; $goals++) {
            $goalProbabilities[$goals] = $this->poissonProbability($goals, $expectedGoals) * 100;
        }
        
        // Find most likely goal count
        $mostLikely = array_search(max($goalProbabilities), $goalProbabilities);
        
        // Calculate over X goals probabilities
        $over0_5 = 100 - $goalProbabilities[0];
        $over1_5 = 100 - ($goalProbabilities[0] + $goalProbabilities[1]);
        $over2_5 = 100 - ($goalProbabilities[0] + $goalProbabilities[1] + $goalProbabilities[2]);
        
        // Determine suggested bet
        $suggested = '';
        $confidence = '';
        
        if ($over0_5 > 80) {
            $suggested = 'Over 0.5 Goals';
            $confidence = $this->getConfidenceLevel($over0_5);
        } elseif ($over1_5 > 60) {
            $suggested = 'Over 1.5 Goals';
            $confidence = $this->getConfidenceLevel($over1_5);
        } elseif ($over0_5 < 60) {
            $suggested = 'Under 0.5 Goals';
            $confidence = $this->getConfidenceLevel(100 - $over0_5);
        } else {
            $suggested = 'Exactly ' . $mostLikely . ' Goals';
            $confidence = 'Medium';
        }
        
        return [
            'expected' => $expectedGoals,
            'over0_5' => round($over0_5, 1),
            'over1_5' => round($over1_5, 1),
            'over2_5' => round($over2_5, 1),
            'probabilities' => array_map(function($prob) { return round($prob, 1); }, $goalProbabilities),
            'mostLikely' => $mostLikely,
            'suggested' => $suggested,
            'confidence' => $confidence
        ];
    }
    
    /**
     * Calculate first to score probability
     */
    private function calculateFirstToScore($homeTeamStats, $awayTeamStats, $h2hAnalysis) {
        // Base probabilities
        $homeProb = 45; // Base probability for home team
        $awayProb = 35; // Base probability for away team
        $noGoalProb = 20; // Base probability for no goal
        
        // Adjust based on team stats
        if (isset($homeTeamStats['scoredFirstRate'])) {
            $homeProb = ($homeProb * 0.4) + ($homeTeamStats['scoredFirstRate'] * 0.6);
        }
        
        if (isset($awayTeamStats['scoredFirstRate'])) {
            $awayProb = ($awayProb * 0.4) + ($awayTeamStats['scoredFirstRate'] * 0.6);
        }
        
        // Adjust based on failed to score rates
        if (isset($homeTeamStats['failedToScoreRate'])) {
            $noGoalProb += $homeTeamStats['failedToScoreRate'] * 0.1;
        }
        
        if (isset($awayTeamStats['failedToScoreRate'])) {
            $noGoalProb += $awayTeamStats['failedToScoreRate'] * 0.1;
        }
        
        // Adjust based on H2H
        if (isset($h2hAnalysis['homeTeamScoredFirstRate'])) {
            $homeProb = ($homeProb * 0.7) + ($h2hAnalysis['homeTeamScoredFirstRate'] * 0.3);
            $awayProb = ($awayProb * 0.7) + ((100 - $h2hAnalysis['homeTeamScoredFirstRate']) * 0.3);
        }
        
        // Normalize to 100%
        $total = $homeProb + $awayProb + $noGoalProb;
        $homeProb = round(($homeProb / $total) * 100, 1);
        $awayProb = round(($awayProb / $total) * 100, 1);
        $noGoalProb = round(($noGoalProb / $total) * 100, 1);
        
        // Determine suggested team
        $suggested = '';
        $confidence = '';
        
        if ($homeProb > $awayProb && $homeProb > $noGoalProb) {
            $suggested = 'Home Team';
            $confidence = $this->getConfidenceLevel($homeProb);
        } elseif ($awayProb > $homeProb && $awayProb > $noGoalProb) {
            $suggested = 'Away Team';
            $confidence = $this->getConfidenceLevel($awayProb);
        } else {
            $suggested = 'No Goal';
            $confidence = $this->getConfidenceLevel($noGoalProb);
        }
        
        return [
            'home' => $homeProb,
            'away' => $awayProb,
            'noGoal' => $noGoalProb,
            'suggested' => $suggested,
            'confidence' => $confidence
        ];
    }
    
    /**
     * Get confidence level based on probability
     * @param float $probability
     * @return string
     */
    private function getConfidenceLevel($probability) {
        if ($probability >= 70) return 'High';
        if ($probability >= 55) return 'Medium';
        return 'Low';
    }
    
    /**
     * Get form points from form array (W=3, D=1, L=0)
     * @param array $form
     * @return int
     */
    private function getFormPoints($form) {
        $points = 0;
        $weight = 1.5; // Most recent match has highest weight
        
        foreach ($form as $result) {
            if ($result === 'W') $points += 3 * $weight;
            elseif ($result === 'D') $points += 1 * $weight;
            $weight -= 0.3; // Reduce weight for older matches
            if ($weight < 0.3) $weight = 0.3;
        }
        
        return $points;
    }
    
    /**
     * Get option with highest probability
     * @param array $options
     * @return string
     */
    private function getHighestProbability($options) {
        arsort($options);
        return key($options);
    }
    
    /**
     * Identify safe bets
     * @param array $matchOutcome
     * @param array $btts
     * @param array $over_under
     * @param array $over1_5
     * @param array $corners
     * @param array $teamGoals
     * @param array $firstToScore
     * @return array
     */
    private function identifySafeBets($matchOutcome, $btts, $over_under, $over1_5, $corners, $teamGoals, $firstToScore) {
        $safeBets = [];
        
        // Only include high confidence bets
        if ($matchOutcome['confidence'] == 'High') {
            $safeBets[] = [
                'type' => 'Match Outcome',
                'bet' => $matchOutcome['suggested'],
                'probability' => max($matchOutcome['homeWin'], $matchOutcome['draw'], $matchOutcome['awayWin'])
            ];
        }
        
        if ($btts['confidence'] == 'High') {
            $safeBets[] = [
                'type' => 'Both Teams to Score',
                'bet' => $btts['suggested'],
                'probability' => max($btts['yes'], $btts['no'])
            ];
        }
        
        if ($over_under['confidence'] == 'High') {
            $safeBets[] = [
                'type' => 'Over/Under 2.5 Goals',
                'bet' => $over_under['suggested'],
                'probability' => max($over_under['over2_5'], $over_under['under2_5'])
            ];
        }
        
        if ($over1_5['confidence'] == 'High') {
            $safeBets[] = [
                'type' => 'Over/Under 1.5 Goals',
                'bet' => $over1_5['suggested'],
                'probability' => max($over1_5['over1_5'], $over1_5['under1_5'])
            ];
        }
        
        if ($corners['confidence'] == 'High') {
            $safeBets[] = [
                'type' => 'Corners',
                'bet' => $corners['suggested'],
                'probability' => $corners['over8_5'] // Using over8.5 as reference
            ];
        }
        
        if ($teamGoals['home']['confidence'] == 'High') {
            $safeBets[] = [
                'type' => 'Home Team Goals',
                'bet' => $teamGoals['home']['suggested'],
                'probability' => max($teamGoals['home']['over0_5'], $teamGoals['home']['over1_5'], $teamGoals['home']['over2_5'])
            ];
        }
        
        if ($teamGoals['away']['confidence'] == 'High') {
            $safeBets[] = [
                'type' => 'Away Team Goals',
                'bet' => $teamGoals['away']['suggested'],
                'probability' => max($teamGoals['away']['over0_5'], $teamGoals['away']['over1_5'], $teamGoals['away']['over2_5'])
            ];
        }
        
        if ($firstToScore['confidence'] == 'High') {
            $safeBets[] = [
                'type' => 'First Team to Score',
                'bet' => $firstToScore['suggested'],
                'probability' => max($firstToScore['home'], $firstToScore['away'], $firstToScore['noGoal'])
            ];
        }
        
        // If no high confidence bets, include medium confidence with highest probability
        if (empty($safeBets)) {
            $allBets = [];
            
            if ($matchOutcome['confidence'] == 'Medium') {
                $allBets[] = [
                    'type' => 'Match Outcome',
                    'bet' => $matchOutcome['suggested'],
                    'probability' => max($matchOutcome['homeWin'], $matchOutcome['draw'], $matchOutcome['awayWin'])
                ];
            }
            
            if ($btts['confidence'] == 'Medium') {
                $allBets[] = [
                    'type' => 'Both Teams to Score',
                    'bet' => $btts['suggested'],
                    'probability' => max($btts['yes'], $btts['no'])
                ];
            }
            
            if ($over_under['confidence'] == 'Medium') {
                $allBets[] = [
                    'type' => 'Over/Under 2.5 Goals',
                    'bet' => $over_under['suggested'],
                    'probability' => max($over_under['over2_5'], $over_under['under2_5'])
                ];
            }
            
            if ($over1_5['confidence'] == 'Medium') {
                $allBets[] = [
                    'type' => 'Over/Under 1.5 Goals',
                    'bet' => $over1_5['suggested'],
                    'probability' => max($over1_5['over1_5'], $over1_5['under1_5'])
                ];
            }
            
            // Add more medium confidence bets
            if ($corners['confidence'] == 'Medium') {
                $allBets[] = [
                    'type' => 'Corners',
                    'bet' => $corners['suggested'],
                    'probability' => $corners['over8_5']
                ];
            }
            
            if ($teamGoals['home']['confidence'] == 'Medium') {
                $allBets[] = [
                    'type' => 'Home Team Goals',
                    'bet' => $teamGoals['home']['suggested'],
                    'probability' => max($teamGoals['home']['over0_5'], $teamGoals['home']['over1_5'])
                ];
            }
            
            if ($teamGoals['away']['confidence'] == 'Medium') {
                $allBets[] = [
                    'type' => 'Away Team Goals',
                    'bet' => $teamGoals['away']['suggested'],
                    'probability' => max($teamGoals['away']['over0_5'], $teamGoals['away']['over1_5'])
                ];
            }
            
            // Sort by probability and take top 3
            usort($allBets, function($a, $b) {
                return $b['probability'] - $a['probability'];
            });
            
            $safeBets = array_slice($allBets, 0, 3);
        }
        
        return $safeBets;
    }
    
    /**
     * Generate reasoning for match outcome recommendation
     */
    private function getMatchOutcomeReasoning($homeTeamStats, $awayTeamStats, $h2hAnalysis, $homeTeamName, $awayTeamName, $suggestion) {
        $reasons = [];
        
        if ($suggestion == 'Home Win') {
            if (isset($homeTeamStats['winRate']) && $homeTeamStats['winRate'] > 50) {
                $reasons[] = "$homeTeamName has a strong win rate of {$homeTeamStats['winRate']}%";
            }
            
            if (isset($homeTeamStats['avgGoalsFor']) && isset($awayTeamStats['avgGoalsFor']) && 
                $homeTeamStats['avgGoalsFor'] > $awayTeamStats['avgGoalsFor']) {
                $reasons[] = "$homeTeamName scores more goals on average ({$homeTeamStats['avgGoalsFor']}) than $awayTeamName ({$awayTeamStats['avgGoalsFor']})";
            }
            
            if (isset($h2hAnalysis['homeTeamWinRate']) && $h2hAnalysis['homeTeamWinRate'] > 50) {
                $reasons[] = "$homeTeamName has won {$h2hAnalysis['homeTeamWinRate']}% of recent head-to-head matches";
            }
            
            $reasons[] = "Home advantage typically gives $homeTeamName a significant edge";
        } 
        elseif ($suggestion == 'Draw') {
            if (isset($homeTeamStats['winRate']) && isset($awayTeamStats['winRate']) && 
                abs($homeTeamStats['winRate'] - $awayTeamStats['winRate']) < 10) {
                $reasons[] = "Both teams have similar win rates ({$homeTeamStats['winRate']}% vs {$awayTeamStats['winRate']}%)";
            }
            
            if (isset($homeTeamStats['avgGoalsFor']) && isset($awayTeamStats['avgGoalsFor']) && 
                abs($homeTeamStats['avgGoalsFor'] - $awayTeamStats['avgGoalsFor']) < 0.5) {
                $reasons[] = "Both teams score similar number of goals ({$homeTeamStats['avgGoalsFor']} vs {$awayTeamStats['avgGoalsFor']})";
            }
            
            if (isset($h2hAnalysis['drawRate']) && $h2hAnalysis['drawRate'] > 30) {
                $reasons[] = "{$h2hAnalysis['drawRate']}% of recent head-to-head matches have ended in draws";
            }
        } 
        else { // Away Win
            if (isset($awayTeamStats['winRate']) && $awayTeamStats['winRate'] > 50) {
                $reasons[] = "$awayTeamName has a strong win rate of {$awayTeamStats['winRate']}%";
            }
            
            if (isset($awayTeamStats['avgGoalsFor']) && isset($homeTeamStats['avgGoalsFor']) && 
                $awayTeamStats['avgGoalsFor'] > $homeTeamStats['avgGoalsFor']) {
                $reasons[] = "$awayTeamName scores more goals on average ({$awayTeamStats['avgGoalsFor']}) than $homeTeamName ({$homeTeamStats['avgGoalsFor']})";
            }
            
            if (isset($h2hAnalysis['awayTeamWinRate']) && $h2hAnalysis['awayTeamWinRate'] > 50) {
                $reasons[] = "$awayTeamName has won {$h2hAnalysis['awayTeamWinRate']}% of recent head-to-head matches";
            }
            
            if (isset($homeTeamStats['form'][0]) && isset($homeTeamStats['form'][1]) && 
                $homeTeamStats['form'][0] === 'L' && $homeTeamStats['form'][1] === 'L') {
                $reasons[] = "$homeTeamName is in poor form, losing their last two matches";
            }
        }
        
        // Add form-based reasoning
        $homeFormPoints = $this->getFormPoints($homeTeamStats['form'] ?? []);
        $awayFormPoints = $this->getFormPoints($awayTeamStats['form'] ?? []);
        
        if ($homeFormPoints > $awayFormPoints + 3) {
            $reasons[] = "$homeTeamName is in significantly better recent form than $awayTeamName";
        } elseif ($awayFormPoints > $homeFormPoints + 3) {
            $reasons[] = "$awayTeamName is in significantly better recent form than $homeTeamName";
        }
        
        return $reasons;
    }
    
    /**
     * Generate reasoning for BTTS recommendation
     */
    private function getBttsReasoning($homeTeamStats, $awayTeamStats, $h2hAnalysis, $homeTeamName, $awayTeamName, $suggestion) {
        $reasons = [];
        
        if ($suggestion == 'Yes') {
            if (isset($homeTeamStats['bttsRate']) && $homeTeamStats['bttsRate'] > 60) {
                $reasons[] = "$homeTeamName's matches see both teams scoring {$homeTeamStats['bttsRate']}% of the time";
            }
            
            if (isset($awayTeamStats['bttsRate']) && $awayTeamStats['bttsRate'] > 60) {
                $reasons[] = "$awayTeamName's matches see both teams scoring {$awayTeamStats['bttsRate']}% of the time";
            }
            
            if (isset($homeTeamStats['cleanSheetRate']) && $homeTeamStats['cleanSheetRate'] < 30) {
                $reasons[] = "$homeTeamName rarely keeps clean sheets (only {$homeTeamStats['cleanSheetRate']}% of matches)";
            }
            
            if (isset($awayTeamStats['failedToScoreRate']) && $awayTeamStats['failedToScoreRate'] < 30) {
                $reasons[] = "$awayTeamName usually manages to score (fails to score in only {$awayTeamStats['failedToScoreRate']}% of matches)";
            }
            
            if (isset($h2hAnalysis['bttsRate']) && $h2hAnalysis['bttsRate'] > 60) {
                $reasons[] = "Both teams have scored in {$h2hAnalysis['bttsRate']}% of recent head-to-head matches";
            }
        } 
        else { // No
            if (isset($homeTeamStats['cleanSheetRate']) && $homeTeamStats['cleanSheetRate'] > 50) {
                $reasons[] = "$homeTeamName keeps clean sheets in {$homeTeamStats['cleanSheetRate']}% of their matches";
            }
            
            if (isset($awayTeamStats['failedToScoreRate']) && $awayTeamStats['failedToScoreRate'] > 40) {
                $reasons[] = "$awayTeamName fails to score in {$awayTeamStats['failedToScoreRate']}% of their matches";
            }
            
            if (isset($homeTeamStats['bttsRate']) && $homeTeamStats['bttsRate'] < 40) {
                $reasons[] = "$homeTeamName's matches rarely see both teams scoring (only {$homeTeamStats['bttsRate']}% of the time)";
            }
            
            if (isset($h2hAnalysis['bttsRate']) && $h2hAnalysis['bttsRate'] < 40) {
                $reasons[] = "Both teams have scored in only {$h2hAnalysis['bttsRate']}% of recent head-to-head matches";
            }
        }
        
        return $reasons;
    }
    
    /**
     * Generate reasoning for Over/Under 2.5 recommendation
     */
    private function getOverUnderReasoning($homeTeamStats, $awayTeamStats, $h2hAnalysis, $homeTeamName, $awayTeamName, $suggestion) {
        $reasons = [];
        
        if ($suggestion == 'Over 2.5') {
            if (isset($homeTeamStats['over2_5Rate']) && $homeTeamStats['over2_5Rate'] > 60) {
                $reasons[] = "{$homeTeamStats['over2_5Rate']}% of $homeTeamName's matches go over 2.5 goals";
            }
            
            if (isset($awayTeamStats['over2_5Rate']) && $awayTeamStats['over2_5Rate'] > 60) {
                $reasons[] = "{$awayTeamStats['over2_5Rate']}% of $awayTeamName's matches go over 2.5 goals";
            }
            
            $totalAvgGoals = (
                ($homeTeamStats['avgGoalsFor'] ?? 0) + 
                ($homeTeamStats['avgGoalsAgainst'] ?? 0) + 
                ($awayTeamStats['avgGoalsFor'] ?? 0) + 
                ($awayTeamStats['avgGoalsAgainst'] ?? 0)
            ) / 2;
            
            if ($totalAvgGoals > 2.7) {
                $reasons[] = "The average of " . number_format($totalAvgGoals, 2) . " goals per match for both teams suggests a high-scoring game";
            }
            
            if (isset($h2hAnalysis['over2_5Rate']) && $h2hAnalysis['over2_5Rate'] > 60) {
                $reasons[] = "{$h2hAnalysis['over2_5Rate']}% of recent head-to-head matches have gone over 2.5 goals";
            }
        } 
        else { // Under 2.5
            if (isset($homeTeamStats['over2_5Rate']) && $homeTeamStats['over2_5Rate'] < 40) {
                $reasons[] = "Only {$homeTeamStats['over2_5Rate']}% of $homeTeamName's matches go over 2.5 goals";
            }
            
            if (isset($awayTeamStats['over2_5Rate']) && $awayTeamStats['over2_5Rate'] < 40) {
                $reasons[] = "Only {$awayTeamStats['over2_5Rate']}% of $awayTeamName's matches go over 2.5 goals";
            }
            
            $totalAvgGoals = (
                ($homeTeamStats['avgGoalsFor'] ?? 0) + 
                ($homeTeamStats['avgGoalsAgainst'] ?? 0) + 
                ($awayTeamStats['avgGoalsFor'] ?? 0) + 
                ($awayTeamStats['avgGoalsAgainst'] ?? 0)
            ) / 2;
            
            if ($totalAvgGoals < 2.3) {
                $reasons[] = "The average of " . number_format($totalAvgGoals, 2) . " goals per match for both teams suggests a low-scoring game";
            }
            
            if (isset($h2hAnalysis['over2_5Rate']) && $h2hAnalysis['over2_5Rate'] < 40) {
                $reasons[] = "Only {$h2hAnalysis['over2_5Rate']}% of recent head-to-head matches have gone over 2.5 goals";
            }
        }
        
        return $reasons;
    }
    
    /**
     * Generate reasoning for Over/Under 1.5 recommendation
     */
    private function getOver1_5Reasoning($homeTeamStats, $awayTeamStats, $h2hAnalysis, $homeTeamName, $awayTeamName, $suggestion) {
        $reasons = [];
        
        if ($suggestion == 'Over 1.5') {
            if (isset($homeTeamStats['over1_5Rate']) && $homeTeamStats['over1_5Rate'] > 70) {
                $reasons[] = "{$homeTeamStats['over1_5Rate']}% of $homeTeamName's matches go over 1.5 goals";
            }
            
            if (isset($awayTeamStats['over1_5Rate']) && $awayTeamStats['over1_5Rate'] > 70) {
                $reasons[] = "{$awayTeamStats['over1_5Rate']}% of $awayTeamName's matches go over 1.5 goals";
            }
            
            $totalAvgGoals = (
                ($homeTeamStats['avgGoalsFor'] ?? 0) + 
                ($homeTeamStats['avgGoalsAgainst'] ?? 0) + 
                ($awayTeamStats['avgGoalsFor'] ?? 0) + 
                ($awayTeamStats['avgGoalsAgainst'] ?? 0)
            ) / 2;
            
            if ($totalAvgGoals > 2.0) {
                $reasons[] = "The average of " . number_format($totalAvgGoals, 2) . " goals per match for both teams is well above the 1.5 threshold";
            }
            
            if (isset($h2hAnalysis['over1_5Rate']) && $h2hAnalysis['over1_5Rate'] > 70) {
                $reasons[] = "{$h2hAnalysis['over1_5Rate']}% of recent head-to-head matches have gone over 1.5 goals";
            }
        } 
        else { // Under 1.5
            if (isset($homeTeamStats['over1_5Rate']) && $homeTeamStats['over1_5Rate'] < 60) {
                $reasons[] = "Only {$homeTeamStats['over1_5Rate']}% of $homeTeamName's matches go over 1.5 goals";
            }
            
            if (isset($awayTeamStats['over1_5Rate']) && $awayTeamStats['over1_5Rate'] < 60) {
                $reasons[] = "Only {$awayTeamStats['over1_5Rate']}% of $awayTeamName's matches go over 1.5 goals";
            }
            
            $totalAvgGoals = (
                ($homeTeamStats['avgGoalsFor'] ?? 0) + 
                ($homeTeamStats['avgGoalsAgainst'] ?? 0) + 
                ($awayTeamStats['avgGoalsFor'] ?? 0) + 
                ($awayTeamStats['avgGoalsAgainst'] ?? 0)
            ) / 2;
            
            if ($totalAvgGoals < 1.7) {
                $reasons[] = "The average of " . number_format($totalAvgGoals, 2) . " goals per match for both teams suggests a very low-scoring game";
            }
            
            if (isset($homeTeamStats['failedToScoreRate']) && isset($awayTeamStats['failedToScoreRate']) &&
                ($homeTeamStats['failedToScoreRate'] > 40 || $awayTeamStats['failedToScoreRate'] > 40)) {
                $reasons[] = "At least one team frequently fails to score, increasing the chance of a low-scoring match";
            }
        }
        
        return $reasons;
    }
    
    /**
     * Generate reasoning for Corners recommendation
     */
    private function getCornersReasoning($homeTeamStats, $awayTeamStats, $h2hAnalysis, $homeTeamName, $awayTeamName, $suggestion) {
        $reasons = [];
        $thresholdPart = explode(' ', $suggestion)[1]; // Extract "8.5", "9.5", etc.
        
        if (strpos($suggestion, 'Over') !== false) {
            if (isset($homeTeamStats['avgCornersFor']) && $homeTeamStats['avgCornersFor'] > 5) {
                $reasons[] = "$homeTeamName averages " . number_format($homeTeamStats['avgCornersFor'], 1) . " corners per match";
            }
            
            if (isset($awayTeamStats['avgCornersFor']) && $awayTeamStats['avgCornersFor'] > 4) {
                $reasons[] = "$awayTeamName averages " . number_format($awayTeamStats['avgCornersFor'], 1) . " corners per match";
            }
            
            $totalExpectedCorners = (($homeTeamStats['avgCornersFor'] ?? 0) + ($awayTeamStats['avgCornersFor'] ?? 0));
            
            if ($totalExpectedCorners > (float)$thresholdPart) {
                $reasons[] = "Combined averages suggest " . number_format($totalExpectedCorners, 1) . " corners, which is above the $thresholdPart threshold";
            }
            
            if (isset($h2hAnalysis['avgCornersPerMatch']) && $h2hAnalysis['avgCornersPerMatch'] > (float)$thresholdPart) {
                $reasons[] = "Head-to-head matches average " . number_format($h2hAnalysis['avgCornersPerMatch'], 1) . " corners";
            }
        } 
        else { // Under
            if (isset($homeTeamStats['avgCornersFor']) && $homeTeamStats['avgCornersFor'] < 5) {
                $reasons[] = "$homeTeamName averages only " . number_format($homeTeamStats['avgCornersFor'], 1) . " corners per match";
            }
            
            if (isset($awayTeamStats['avgCornersFor']) && $awayTeamStats['avgCornersFor'] < 4) {
                $reasons[] = "$awayTeamName averages only " . number_format($awayTeamStats['avgCornersFor'], 1) . " corners per match";
            }
            
            $totalExpectedCorners = (($homeTeamStats['avgCornersFor'] ?? 0) + ($awayTeamStats['avgCornersFor'] ?? 0));
            
            if ($totalExpectedCorners < (float)$thresholdPart) {
                $reasons[] = "Combined averages suggest " . number_format($totalExpectedCorners, 1) . " corners, which is below the $thresholdPart threshold";
            }
            
            if (isset($h2hAnalysis['avgCornersPerMatch']) && $h2hAnalysis['avgCornersPerMatch'] < (float)$thresholdPart) {
                $reasons[] = "Head-to-head matches average only " . number_format($h2hAnalysis['avgCornersPerMatch'], 1) . " corners";
            }
        }
        
        return $reasons;
    }
    
    /**
     * Generate reasoning for Team Goals recommendation
     */
    private function getTeamGoalsReasoning($homeTeamStats, $awayTeamStats, $h2hAnalysis, $homeTeamName, $awayTeamName, $homeGoals, $awayGoals) {
        $reasons = [
            'home' => [],
            'away' => []
        ];
        
        // Home team reasoning
        if (strpos($homeGoals['suggested'], 'Over') !== false) {
            $threshold = str_replace(['Over ', ' Goals'], '', $homeGoals['suggested']);
            
            if (isset($homeTeamStats['avgGoalsFor']) && $homeTeamStats['avgGoalsFor'] > (float)$threshold) {
                $reasons['home'][] = "$homeTeamName averages " . number_format($homeTeamStats['avgGoalsFor'], 2) . " goals per match";
            }
            
            if (isset($awayTeamStats['avgGoalsAgainst']) && $awayTeamStats['avgGoalsAgainst'] > (float)$threshold) {
                $reasons['home'][] = "$awayTeamName concedes " . number_format($awayTeamStats['avgGoalsAgainst'], 2) . " goals per match";
            }
            
            if (isset($homeTeamStats['failedToScoreRate']) && $homeTeamStats['failedToScoreRate'] < 30) {
                $reasons['home'][] = "$homeTeamName scores in " . (100 - $homeTeamStats['failedToScoreRate']) . "% of their matches";
            }
            
            if (isset($h2hAnalysis['avgHomeTeamGoals']) && $h2hAnalysis['avgHomeTeamGoals'] > (float)$threshold) {
                $reasons['home'][] = "$homeTeamName averages " . number_format($h2hAnalysis['avgHomeTeamGoals'], 2) . " goals in head-to-head matches";
            }
        } 
        else if (strpos($homeGoals['suggested'], 'Under') !== false) {
            $threshold = str_replace(['Under ', ' Goals'], '', $homeGoals['suggested']);
            
            if (isset($homeTeamStats['avgGoalsFor']) && $homeTeamStats['avgGoalsFor'] < (float)$threshold) {
                $reasons['home'][] = "$homeTeamName averages only " . number_format($homeTeamStats['avgGoalsFor'], 2) . " goals per match";
            }
            
            if (isset($homeTeamStats['failedToScoreRate']) && $homeTeamStats['failedToScoreRate'] > 30) {
                $reasons['home'][] = "$homeTeamName fails to score in " . $homeTeamStats['failedToScoreRate'] . "% of their matches";
            }
            
            if (isset($awayTeamStats['cleanSheetRate']) && $awayTeamStats['cleanSheetRate'] > 40) {
                $reasons['home'][] = "$awayTeamName keeps clean sheets in " . $awayTeamStats['cleanSheetRate'] . "% of their matches";
            }
        }
        else if (strpos($homeGoals['suggested'], 'Exactly') !== false) {
            $goalCount = str_replace(['Exactly ', ' Goals'], '', $homeGoals['suggested']);
            
            if (isset($homeTeamStats['goalDistribution'][$goalCount])) {
                $reasons['home'][] = "$homeTeamName scores exactly $goalCount goals in " . 
                                    $homeTeamStats['goalDistribution'][$goalCount]['percentage'] . "% of their matches";
            }
            
            if (isset($homeTeamStats['avgGoalsFor']) && abs($homeTeamStats['avgGoalsFor'] - (float)$goalCount) < 0.5) {
                $reasons['home'][] = "$homeTeamName's average of " . number_format($homeTeamStats['avgGoalsFor'], 2) . 
                                   " goals is close to $goalCount";
            }
        }
        
        // Away team reasoning
        if (strpos($awayGoals['suggested'], 'Over') !== false) {
            $threshold = str_replace(['Over ', ' Goals'], '', $awayGoals['suggested']);
            
            if (isset($awayTeamStats['avgGoalsFor']) && $awayTeamStats['avgGoalsFor'] > (float)$threshold) {
                $reasons['away'][] = "$awayTeamName averages " . number_format($awayTeamStats['avgGoalsFor'], 2) . " goals per match";
            }
            
            if (isset($homeTeamStats['avgGoalsAgainst']) && $homeTeamStats['avgGoalsAgainst'] > (float)$threshold) {
                $reasons['away'][] = "$homeTeamName concedes " . number_format($homeTeamStats['avgGoalsAgainst'], 2) . " goals per match";
            }
            
            if (isset($awayTeamStats['failedToScoreRate']) && $awayTeamStats['failedToScoreRate'] < 30) {
                $reasons['away'][] = "$awayTeamName scores in " . (100 - $awayTeamStats['failedToScoreRate']) . "% of their matches";
            }
            
            if (isset($h2hAnalysis['avgAwayTeamGoals']) && $h2hAnalysis['avgAwayTeamGoals'] > (float)$threshold) {
                $reasons['away'][] = "$awayTeamName averages " . number_format($h2hAnalysis['avgAwayTeamGoals'], 2) . " goals in head-to-head matches";
            }
        } 
        else if (strpos($awayGoals['suggested'], 'Under') !== false) {
            $threshold = str_replace(['Under ', ' Goals'], '', $awayGoals['suggested']);
            
            if (isset($awayTeamStats['avgGoalsFor']) && $awayTeamStats['avgGoalsFor'] < (float)$threshold) {
                $reasons['away'][] = "$awayTeamName averages only " . number_format($awayTeamStats['avgGoalsFor'], 2) . " goals per match";
            }
            
            if (isset($awayTeamStats['failedToScoreRate']) && $awayTeamStats['failedToScoreRate'] > 30) {
                $reasons['away'][] = "$awayTeamName fails to score in " . $awayTeamStats['failedToScoreRate'] . "% of their matches";
            }
            
            if (isset($homeTeamStats['cleanSheetRate']) && $homeTeamStats['cleanSheetRate'] > 40) {
                $reasons['away'][] = "$homeTeamName keeps clean sheets in " . $homeTeamStats['cleanSheetRate'] . "% of their matches";
            }
        }
        else if (strpos($awayGoals['suggested'], 'Exactly') !== false) {
            $goalCount = str_replace(['Exactly ', ' Goals'], '', $awayGoals['suggested']);
            
            if (isset($awayTeamStats['goalDistribution'][$goalCount])) {
                $reasons['away'][] = "$awayTeamName scores exactly $goalCount goals in " . 
                                    $awayTeamStats['goalDistribution'][$goalCount]['percentage'] . "% of their matches";
            }
            
            if (isset($awayTeamStats['avgGoalsFor']) && abs($awayTeamStats['avgGoalsFor'] - (float)$goalCount) < 0.5) {
                $reasons['away'][] = "$awayTeamName's average of " . number_format($awayTeamStats['avgGoalsFor'], 2) . 
                                   " goals is close to $goalCount";
            }
        }
        
        return $reasons;
    }
    
    /**
     * Generate reasoning for First To Score recommendation
     */
    private function getFirstToScoreReasoning($homeTeamStats, $awayTeamStats, $h2hAnalysis, $homeTeamName, $awayTeamName, $suggestion) {
        $reasons = [];
        
        if ($suggestion == 'Home Team') {
            if (isset($homeTeamStats['scoredFirstRate']) && $homeTeamStats['scoredFirstRate'] > 50) {
                $reasons[] = "$homeTeamName scores first in {$homeTeamStats['scoredFirstRate']}% of their matches";
            }
            
            if (isset($h2hAnalysis['homeTeamScoredFirstRate']) && $h2hAnalysis['homeTeamScoredFirstRate'] > 50) {
                $reasons[] = "$homeTeamName has scored first in {$h2hAnalysis['homeTeamScoredFirstRate']}% of head-to-head matches";
            }
            
            if (isset($homeTeamStats['avgGoalsFor']) && isset($awayTeamStats['avgGoalsFor']) && 
                $homeTeamStats['avgGoalsFor'] > $awayTeamStats['avgGoalsFor']) {
                $reasons[] = "$homeTeamName scores more goals on average ({$homeTeamStats['avgGoalsFor']}) than $awayTeamName ({$awayTeamStats['avgGoalsFor']})";
            }
            
            $reasons[] = "Home advantage often gives teams an early edge in matches";
        } 
        elseif ($suggestion == 'Away Team') {
            if (isset($awayTeamStats['scoredFirstRate']) && $awayTeamStats['scoredFirstRate'] > 50) {
                $reasons[] = "$awayTeamName scores first in {$awayTeamStats['scoredFirstRate']}% of their matches";
            }
            
            if (isset($h2hAnalysis['homeTeamScoredFirstRate']) && $h2hAnalysis['homeTeamScoredFirstRate'] < 50) {
                $reasons[] = "$awayTeamName has scored first in " . (100 - $h2hAnalysis['homeTeamScoredFirstRate']) . "% of head-to-head matches";
            }
            
            if (isset($awayTeamStats['avgGoalsFor']) && isset($homeTeamStats['avgGoalsFor']) && 
                $awayTeamStats['avgGoalsFor'] > $homeTeamStats['avgGoalsFor']) {
                $reasons[] = "$awayTeamName scores more goals on average ({$awayTeamStats['avgGoalsFor']}) than $homeTeamName ({$homeTeamStats['avgGoalsFor']})";
            }
            
            if (isset($homeTeamStats['failedToScoreRate']) && $homeTeamStats['failedToScoreRate'] > 30) {
                $reasons[] = "$homeTeamName fails to score in {$homeTeamStats['failedToScoreRate']}% of their matches";
            }
        }
        else { // No Goal
            if (isset($homeTeamStats['failedToScoreRate']) && isset($awayTeamStats['failedToScoreRate']) && 
                $homeTeamStats['failedToScoreRate'] > 30 && $awayTeamStats['failedToScoreRate'] > 30) {
                $reasons[] = "Both teams frequently fail to score in matches";
            }
            
            if (isset($homeTeamStats['cleanSheetRate']) && isset($awayTeamStats['cleanSheetRate']) && 
                $homeTeamStats['cleanSheetRate'] > 40 && $awayTeamStats['cleanSheetRate'] > 40) {
                $reasons[] = "Both teams have strong defensive records, with clean sheet rates of {$homeTeamStats['cleanSheetRate']}% and {$awayTeamStats['cleanSheetRate']}%";
            }
            
            $reasons[] = "The expected low-scoring nature of this match increases the chances of no goals being scored";
        }
        
        return $reasons;
    }
}