<?php
/**
 * Cache Manager Class
 * Path: classes/CacheManager.php
 * 
 * Enhanced caching system to minimize API calls
 */

class CacheManager {
    private $cache_dir;
    private $default_expiry = 86400; // 24 hours in seconds
    
    /**
     * Constructor
     */
    public function __construct() {
        $this->cache_dir = __DIR__ . '/../cache/';
        
        // Create cache directory if it doesn't exist
        if (!file_exists($this->cache_dir)) {
            mkdir($this->cache_dir, 0755, true);
        }
    }
    
    /**
     * Get cache path for a key
     * @param string $key
     * @return string
     */
    private function getCachePath($key) {
        return $this->cache_dir . md5($key) . '.json';
    }
    
    /**
     * Check if valid cache exists
     * @param string $key
     * @param int $expiry Cache expiry in seconds
     * @return bool
     */
    public function hasValidCache($key, $expiry = null) {
        $expiry = $expiry ?? $this->default_expiry;
        $cache_file = $this->getCachePath($key);
        
        return file_exists($cache_file) && (time() - filemtime($cache_file) < $expiry);
    }
    
    /**
     * Get cached data
     * @param string $key
     * @return mixed|null
     */
    public function get($key) {
        $cache_file = $this->getCachePath($key);
        
        if (file_exists($cache_file)) {
            $data = json_decode(file_get_contents($cache_file), true);
            return $data;
        }
        
        return null;
    }
    
    /**
     * Store data in cache
     * @param string $key
     * @param mixed $data
     * @return bool
     */
    public function set($key, $data) {
        $cache_file = $this->getCachePath($key);
        return file_put_contents($cache_file, json_encode($data)) !== false;
    }
    
    /**
     * Clear specific cache
     * @param string $key
     * @return bool
     */
    public function clear($key) {
        $cache_file = $this->getCachePath($key);
        
        if (file_exists($cache_file)) {
            return unlink($cache_file);
        }
        
        return false;
    }
    
    /**
     * Clear all cache files
     * @return bool
     */
    public function clearAll() {
        $files = glob($this->cache_dir . '*.json');
        
        foreach ($files as $file) {
            unlink($file);
        }
        
        return true;
    }
    
    /**
     * Get or set data with custom cache duration
     * @param string $key
     * @param callable $dataCallback Function to generate data if not cached
     * @param int $expiry Cache expiry in seconds
     * @return mixed
     */
    public function remember($key, $dataCallback, $expiry = null) {
        if ($this->hasValidCache($key, $expiry)) {
            return $this->get($key);
        }
        
        $data = $dataCallback();
        $this->set($key, $data);
        return $data;
    }
    
    /**
     * Get cached data with different expiry for different data types
     * @param string $key
     * @param callable $dataCallback Function to generate data if not cached
     * @param string $dataType Type of data for different expiry times
     * @return mixed
     */
    public function smartCache($key, $dataCallback, $dataType = 'default') {
        // Different expiry times based on data type
        $expiry_times = [
            'fixtures' => 21600,    // Match fixtures - 6 hours
            'standings' => 86400,   // League standings - 24 hours
            'teams' => 604800,      // Team info - 1 week
            'competitions' => 604800, // Competition info - 1 week
            'default' => 3600       // Default - 1 hour
        ];
        
        $expiry = $expiry_times[$dataType] ?? $expiry_times['default'];
        
        return $this->remember($key, $dataCallback, $expiry);
    }
}
?>