<?php
/**
 * Football API Client - Updated with Enhanced Caching
 * Path: classes/FootballAPI.php
 */

require_once 'CacheManager.php';

class FootballAPI {
    private $api_key;
    private $base_url;
    private $cache;
    
    // League code constants for all supported leagues
    const LEAGUES = [
        'PL' => ['name' => 'Premier League', 'country' => 'England'],
        'PD' => ['name' => 'La Liga', 'country' => 'Spain'],
        'BL1' => ['name' => 'Bundesliga', 'country' => 'Germany'],
        'FL1' => ['name' => 'Ligue 1', 'country' => 'France'],
        'SA' => ['name' => 'Serie A', 'country' => 'Italy'],
        'PPL' => ['name' => 'Primeira Liga', 'country' => 'Portugal'],
        'DED' => ['name' => 'Eredivisie', 'country' => 'Netherlands'],
        'SPL' => ['name' => 'Scottish Premier League', 'country' => 'Scotland'],
        'SSL' => ['name' => 'Saudi Pro League', 'country' => 'Saudi Arabia'],
        // Cup competitions
        'CL' => ['name' => 'UEFA Champions League', 'country' => 'Europe'],
        'EL' => ['name' => 'UEFA Europa League', 'country' => 'Europe'],
        'EC' => ['name' => 'UEFA Conference League', 'country' => 'Europe'],
        'FAC' => ['name' => 'FA Cup', 'country' => 'England'],
        'CDR' => ['name' => 'Copa del Rey', 'country' => 'Spain'],
        'DFB' => ['name' => 'DFB Pokal', 'country' => 'Germany'],
        'CDF' => ['name' => 'Coupe de France', 'country' => 'France'],
        'CI' => ['name' => 'Coppa Italia', 'country' => 'Italy']
    ];
    
    /**
     * Constructor
     */
    public function __construct() {
        $this->api_key = FOOTBALL_API_KEY;
        $this->base_url = FOOTBALL_API_BASE_URL;
        $this->cache = new CacheManager();
    }
    
    /**
     * Get all supported leagues
     * @return array
     */
    public function getSupportedLeagues() {
        return self::LEAGUES;
    }
    
    /**
     * Get available competitions (leagues)
     * @return array
     */
    public function getCompetitions() {
        return $this->cache->smartCache('competitions', function() {
            return $this->makeRequest('competitions');
        }, 'competitions');
    }
    
    /**
     * Get league standings
     * @param string $league_code
     * @return array
     */
    public function getLeagueStandings($league_code) {
        return $this->cache->smartCache('standings_' . $league_code, function() use ($league_code) {
            return $this->makeRequest("competitions/{$league_code}/standings");
        }, 'standings');
    }
    
    /**
     * Get teams for a specific league
     * @param string $league_code
     * @return array
     */
    public function getTeams($league_code) {
        return $this->cache->smartCache('teams_' . $league_code, function() use ($league_code) {
            $standings = $this->getLeagueStandings($league_code);
            
            if (!isset($standings['standings'][0]['table'])) {
                return [];
            }
            
            $teams = [];
            foreach ($standings['standings'][0]['table'] as $item) {
                $teams[] = [
                    'id' => $item['team']['id'],
                    'name' => $item['team']['name'],
                    'crest' => $item['team']['crest'] ?? null,
                    'position' => $item['position']
                ];
            }
            
            return $teams;
        }, 'teams');
    }
    
    /**
     * Get team details by ID
     * @param int $team_id
     * @return array
     */
    public function getTeam($team_id) {
        return $this->cache->smartCache('team_' . $team_id, function() use ($team_id) {
            return $this->makeRequest("teams/{$team_id}");
        }, 'teams');
    }
    
    /**
     * Get matches for a specific date across multiple competitions
     * @param string $date Date in YYYY-MM-DD format
     * @param array $competitions Array of competition codes to include
     * @return array
     */
    public function getMatchesByDate($date, $competitions = []) {
        $cache_key = 'matches_date_' . $date . '_' . implode('_', $competitions);
        
        return $this->cache->smartCache($cache_key, function() use ($date, $competitions) {
            $params = [
                'date' => $date
            ];
            
            $result = $this->makeRequest("matches", $params);
            
            // Filter by competitions if specified
            if (!empty($competitions) && !empty($result['matches'])) {
                $filtered_matches = [];
                
                foreach ($result['matches'] as $match) {
                    if (in_array($match['competition']['code'], $competitions)) {
                        $filtered_matches[] = $match;
                    }
                }
                
                $result['matches'] = $filtered_matches;
                $result['count'] = count($filtered_matches);
            }
            
            return $result;
        }, 'fixtures');
    }
    
    /**
     * Get upcoming matches for a team
     * @param int $team_id
     * @param int $limit
     * @return array
     */
    public function getUpcomingMatches($team_id, $limit = 5) {
        $params = [
            'status' => 'SCHEDULED',
            'limit' => $limit
        ];
        
        $cache_key = 'upcoming_matches_' . $team_id . '_' . $limit;
        
        return $this->cache->smartCache($cache_key, function() use ($team_id, $params) {
            $result = $this->makeRequest("teams/{$team_id}/matches", $params);
            return $result['matches'] ?? [];
        }, 'fixtures');
    }
    
    /**
     * Get all upcoming matches for a league
     * @param string $league_code
     * @param int $days_ahead How many days ahead to look
     * @return array
     */
    public function getLeagueMatches($league_code, $days_ahead = 7) {
        $params = [
            'status' => 'SCHEDULED',
            'dateFrom' => date('Y-m-d'),
            'dateTo' => date('Y-m-d', strtotime("+{$days_ahead} days"))
        ];
        
        $cache_key = 'league_matches_' . $league_code . '_' . $days_ahead;
        
        return $this->cache->smartCache($cache_key, function() use ($league_code, $params) {
            $result = $this->makeRequest("competitions/{$league_code}/matches", $params);
            return $result['matches'] ?? [];
        }, 'fixtures');
    }
    
    /**
     * Get match details
     * @param int $match_id
     * @return array
     */
    public function getMatch($match_id) {
        return $this->cache->smartCache('match_' . $match_id, function() use ($match_id) {
            return $this->makeRequest("matches/{$match_id}");
        }, 'fixtures');
    }
    
    /**
     * Get team's recent matches
     * @param int $team_id
     * @param int $limit
     * @return array
     */
    public function getTeamMatches($team_id, $limit = 10) {
        $params = [
            'status' => 'FINISHED',
            'limit' => $limit
        ];
        
        $cache_key = 'team_matches_' . $team_id . '_' . $limit;
        
        return $this->cache->smartCache($cache_key, function() use ($team_id, $params) {
            $result = $this->makeRequest("teams/{$team_id}/matches", $params);
            return $result['matches'] ?? [];
        }, 'default');
    }
    
    /**
     * Get head-to-head matches between two teams
     * @param int $team1_id
     * @param int $team2_id
     * @param int $limit
     * @return array
     */
    public function getHeadToHead($team1_id, $team2_id, $limit = 5) {
        $cache_key = 'h2h_' . min($team1_id, $team2_id) . '_' . max($team1_id, $team2_id) . '_' . $limit;
        
        return $this->cache->smartCache($cache_key, function() use ($team1_id, $team2_id, $limit) {
            $team1_matches = $this->getTeamMatches($team1_id, 50);
            
            $h2h_matches = [];
            foreach ($team1_matches as $match) {
                if (($match['homeTeam']['id'] == $team1_id && $match['awayTeam']['id'] == $team2_id) ||
                    ($match['homeTeam']['id'] == $team2_id && $match['awayTeam']['id'] == $team1_id)) {
                    $h2h_matches[] = $match;
                    if (count($h2h_matches) >= $limit) {
                        break;
                    }
                }
            }
            
            return $h2h_matches;
        }, 'default');
    }
    
    /**
     * Make API request with error handling
     * @param string $endpoint
     * @param array $params
     * @return array
     */
    private function makeRequest($endpoint, $params = []) {
        // Build URL with parameters
        $url = $this->base_url . $endpoint;
        if (!empty($params)) {
            $url .= (strpos($url, '?') === false ? '?' : '&') . http_build_query($params);
        }
        
        // Make API request
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_HTTPHEADER, [
            "X-Auth-Token: {$this->api_key}"
        ]);
        
        $response = curl_exec($ch);
        $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
        curl_close($ch);
        
        if ($http_code === 200) {
            return json_decode($response, true);
        } elseif ($http_code === 429) {
            // Rate limit exceeded
            throw new Exception("API rate limit exceeded. Please try again later.");
        } else {
            $error = json_decode($response, true);
            throw new Exception("API Error: " . ($error['message'] ?? "HTTP Code: $http_code"));
        }
    }
}
?>