<?php
/**
 * Dashboard Page (Updated with daily matches across leagues)
 * Path: dashboard.php
 */

// Include required files
require_once 'includes/config.php';
require_once 'includes/db.php';
require_once 'includes/functions.php';

// Check if user is logged in
requireLogin();

// Load classes
require_once 'classes/FootballAPI.php';
require_once 'classes/CacheManager.php';

$footballAPI = new FootballAPI();
$cache = new CacheManager();

// Get today's date
$current_date = date('Y-m-d');

// Get competition filter from URL or use default (all)
$competition_filter = isset($_GET['competition']) ? $_GET['competition'] : 'all';

// Get supported leagues
$supported_leagues = $footballAPI->getSupportedLeagues();

// Try to get matches for today
try {
    // If we're showing all competitions, collect them all
    if ($competition_filter === 'all') {
        $competitions_to_show = array_keys($supported_leagues);
    } else {
        $competitions_to_show = [$competition_filter];
    }
    
    // Get today's matches
    $daily_matches = $footballAPI->getMatchesByDate($current_date, $competitions_to_show);
    
    // Organize matches by competition
    $matches_by_competition = [];
    
    if (!empty($daily_matches['matches'])) {
        foreach ($daily_matches['matches'] as $match) {
            $comp_code = $match['competition']['code'];
            
            if (!isset($matches_by_competition[$comp_code])) {
                $matches_by_competition[$comp_code] = [
                    'name' => $match['competition']['name'],
                    'code' => $comp_code,
                    'matches' => []
                ];
            }
            
            $matches_by_competition[$comp_code]['matches'][] = $match;
        }
    }
} catch (Exception $e) {
    $_SESSION['message'] = 'Error fetching matches: ' . $e->getMessage();
    $_SESSION['message_type'] = 'error';
    $matches_by_competition = [];
}

// Page variables
$page_title = 'Dashboard | ' . APP_NAME;
$body_class = 'dashboard-page';
$extra_css = 'assets/css/dashboard.css';

// Include header
include 'includes/header.php';
?>

<div class="container">
    <section class="welcome-section">
        <div class="row">
            <div class="col-md-8">
                <h1>Welcome to <?php echo APP_NAME; ?></h1>
                <p class="lead">Your intelligent assistant for football betting strategies. Analysis, trends, and smart recommendations to help you bet smarter, not harder.</p>
            </div>
        </div>
    </section>
    
    <section class="daily-matches-section">
        <div class="section-header">
            <h2>Today's Matches (<?php echo date('F j, Y'); ?>)</h2>
            <div class="competition-filter">
                <form action="" method="get" id="competitionForm">
                    <label for="competition">Filter by competition:</label>
                    <select name="competition" id="competition" class="form-control" onchange="this.form.submit()">
                        <option value="all" <?php echo $competition_filter === 'all' ? 'selected' : ''; ?>>All Competitions</option>
                        <?php foreach ($supported_leagues as $code => $league): ?>
                            <option value="<?php echo $code; ?>" <?php echo $competition_filter === $code ? 'selected' : ''; ?>>
                                <?php echo $league['name']; ?> (<?php echo $league['country']; ?>)
                            </option>
                        <?php endforeach; ?>
                    </select>
                </form>
            </div>
        </div>
        
        <?php if (empty($matches_by_competition)): ?>
            <div class="alert alert-info">
                No matches scheduled for today in the selected competitions.
            </div>
        <?php else: ?>
            <div class="matches-accordion">
                <?php foreach ($matches_by_competition as $comp_code => $competition): ?>
                    <div class="competition-block">
                        <div class="competition-header" data-toggle="collapse" data-target="#competition-<?php echo $comp_code; ?>">
                            <h3><?php echo $competition['name']; ?></h3>
                            <span class="toggle-icon">+</span>
                        </div>
                        
                        <div id="competition-<?php echo $comp_code; ?>" class="competition-matches collapse <?php echo $competition_filter === $comp_code ? 'show' : ''; ?>">
                            <div class="row">
                                <?php foreach ($competition['matches'] as $match): ?>
                                    <div class="col col-lg-4 col-md-6">
                                        <div class="match-card">
                                            <div class="match-header">
                                                <div class="match-date"><?php echo formatDate($match['utcDate']); ?></div>
                                                <div class="match-status"><?php echo $match['status']; ?></div>
                                            </div>
                                            <div class="match-body">
                                                <div class="match-team home-team">
                                                    <div class="team-name"><?php echo $match['homeTeam']['name']; ?></div>
                                                </div>
                                                <div class="match-vs">VS</div>
                                                <div class="match-team away-team">
                                                    <div class="team-name"><?php echo $match['awayTeam']['name']; ?></div>
                                                </div>
                                            </div>
                                            <div class="match-footer">
                                                <a href="match-analysis.php?league=<?php echo $comp_code; ?>&home=<?php echo $match['homeTeam']['id']; ?>&away=<?php echo $match['awayTeam']['id']; ?>" class="btn btn-primary">Analyze Match</a>
                                            </div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php endif; ?>
    </section>
    
    <section class="leagues-section">
        <h2>Analyze Matches by League</h2>
        <p>Choose a football league to analyze upcoming matches and get betting recommendations.</p>
        
        <div class="row">
            <?php foreach ($supported_leagues as $code => $league): ?>
                <div class="col col-md-3 col-sm-4 col-6">
                    <a href="match-analysis.php?league=<?php echo $code; ?>" class="card league-card">
                        <div class="league-name"><?php echo $league['name']; ?></div>
                        <div class="league-country"><?php echo $league['country']; ?></div>
                    </a>
                </div>
            <?php endforeach; ?>
        </div>
    </section>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Toggle competition matches
    document.querySelectorAll('.competition-header').forEach(function(header) {
        header.addEventListener('click', function() {
            this.classList.toggle('active');
            var icon = this.querySelector('.toggle-icon');
            icon.textContent = icon.textContent === '+' ? '-' : '+';
        });
    });
});
</script>

<?php
// Include footer
include 'includes/footer.php';
?>