<?php
/**
 * Helper functions
 * Path: includes/functions.php
 */

/**
 * Sanitize user input
 * @param string $data
 * @return string
 */
function sanitize($data) {
    global $conn;
    $data = trim($data);
    $data = stripslashes($data);
    $data = htmlspecialchars($data);
    $data = $conn->real_escape_string($data);
    return $data;
}

/**
 * Check if user is logged in
 * @return bool
 */
function isLoggedIn() {
    return isset($_SESSION['user_id']);
}

/**
 * Redirect to a URL
 * @param string $url
 */
function redirect($url) {
    header("Location: $url");
    exit;
}

/**
 * Check if user is logged in, if not redirect to login page
 */
function requireLogin() {
    if (!isLoggedIn()) {
        $_SESSION['message'] = "You must be logged in to access this page";
        $_SESSION['message_type'] = "error";
        redirect('index.php');
    }
}

/**
 * Display alert message
 * @return string
 */
function displayMessage() {
    if (isset($_SESSION['message'])) {
        $message = $_SESSION['message'];
        $type = isset($_SESSION['message_type']) ? $_SESSION['message_type'] : 'info';
        
        // Clear message
        unset($_SESSION['message']);
        unset($_SESSION['message_type']);
        
        return '<div class="alert alert-' . $type . '">' . $message . '</div>';
    }
    return '';
}

/**
 * Get user data by ID
 * @param int $user_id
 * @return array|null
 */
function getUserById($user_id) {
    global $conn;
    
    $user_id = (int) $user_id;
    $sql = "SELECT id, username, email, created_at FROM users WHERE id = ?";
    
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("i", $user_id);
    $stmt->execute();
    
    $result = $stmt->get_result();
    
    if ($result->num_rows === 1) {
        return $result->fetch_assoc();
    }
    
    return null;
}

/**
 * Make API request with caching
 * @param string $endpoint
 * @param array $params
 * @param int $cache_time in seconds, default 3600 (1 hour)
 * @return array
 */
function makeApiRequest($endpoint, $params = [], $cache_time = 3600) {
    $cache_dir = __DIR__ . '/../cache/';
    
    // Create cache directory if it doesn't exist
    if (!file_exists($cache_dir)) {
        mkdir($cache_dir, 0755, true);
    }
    
    // Create cache key from endpoint and params
    $cache_key = md5($endpoint . serialize($params));
    $cache_file = $cache_dir . $cache_key . '.json';
    
    // Check if valid cache exists
    if (file_exists($cache_file) && (time() - filemtime($cache_file) < $cache_time)) {
        return json_decode(file_get_contents($cache_file), true);
    }
    
    // Build URL with parameters
    $url = FOOTBALL_API_BASE_URL . $endpoint;
    if (!empty($params)) {
        $url .= (strpos($url, '?') === false ? '?' : '&') . http_build_query($params);
    }
    
    // Make API request
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_HTTPHEADER, [
        "X-Auth-Token: " . FOOTBALL_API_KEY
    ]);
    
    $response = curl_exec($ch);
    $http_code = curl_getinfo($ch, CURLINFO_HTTP_CODE);
    curl_close($ch);
    
    if ($http_code === 200) {
        // Cache successful response
        file_put_contents($cache_file, $response);
        return json_decode($response, true);
    } else {
        $error = json_decode($response, true);
        throw new Exception("API Error: " . ($error['message'] ?? "HTTP Code: $http_code"));
    }
}

/**
 * Format date for display
 * @param string $date_str
 * @param string $format
 * @return string
 */
function formatDate($date_str, $format = 'M d, Y H:i') {
    $date = new DateTime($date_str);
    return $date->format($format);
}

/**
 * Format a number with percentage sign
 * @param float $value
 * @return string
 */
function formatPercent($value) {
    return number_format($value, 1) . '%';
}
?>