<?php
/**
 * Match Analysis Page (Updated with Enhanced Betting Markets)
 * Path: match-analysis.php
 */

// Include required files
require_once 'includes/config.php';
require_once 'includes/db.php';
require_once 'includes/functions.php';

// Check if user is logged in
requireLogin();

// Load necessary classes
require_once 'classes/FootballAPI.php';
require_once 'classes/BetAnalyzer.php';
require_once 'classes/CacheManager.php';

$footballAPI = new FootballAPI();
$betAnalyzer = new BetAnalyzer();
$cache = new CacheManager();

// Get league code from URL or set default to PL (Premier League)
$league_code = isset($_GET['league']) ? $_GET['league'] : 'PL';

// Initialize variables
$teams = [];
$homeTeam = null;
$awayTeam = null;
$analysis = null;
$error = null;

// Try to get teams for the selected league
try {
    $teams = $footballAPI->getTeams($league_code);
} catch (Exception $e) {
    $error = 'Error fetching teams: ' . $e->getMessage();
}

// Check if specific teams are selected for analysis
if (isset($_GET['home']) && isset($_GET['away'])) {
    $homeTeamId = (int)$_GET['home'];
    $awayTeamId = (int)$_GET['away'];
    
    try {
        // Get team details
        $homeTeam = $footballAPI->getTeam($homeTeamId);
        $awayTeam = $footballAPI->getTeam($awayTeamId);
        
        // Analyze match
        $analysis = $betAnalyzer->analyzeMatch($homeTeamId, $awayTeamId);
    } catch (Exception $e) {
        $error = 'Error analyzing match: ' . $e->getMessage();
    }
}

// Leagues data
$leagues = $footballAPI->getSupportedLeagues();

// Page variables
$page_title = 'Match Analysis | ' . APP_NAME;
$body_class = 'analysis-page';
$extra_css = 'assets/css/analysis.css';
$extra_js = 'assets/js/analysis.js';

// Include header
include 'includes/header.php';
?>

<div class="container">
    <section class="selection-section">
        <h1>Match Analysis</h1>
        <p class="lead">Select teams to analyze and get betting recommendations</p>
        
        <?php if ($error): ?>
            <div class="alert alert-error"><?php echo $error; ?></div>
        <?php endif; ?>
        
        <div class="card">
            <div class="card-header">Select Teams</div>
            <div class="card-body">
                <form action="match-analysis.php" method="get" id="analysisForm">
                    <div class="form-group">
                        <label for="league" class="form-label">League</label>
                        <select name="league" id="league" class="form-control" required>
                            <?php foreach ($leagues as $code => $league_data): ?>
                                <option value="<?php echo $code; ?>" <?php echo $league_code === $code ? 'selected' : ''; ?>>
                                    <?php echo $league_data['name']; ?> (<?php echo $league_data['country']; ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    
                    <div class="form-row">
                        <div class="form-group col-md-6">
                            <label for="home" class="form-label">Home Team</label>
                            <select name="home" id="home" class="form-control" required>
                                <option value="">Select Home Team</option>
                                <?php foreach ($teams as $team): ?>
                                    <option value="<?php echo $team['id']; ?>" <?php echo (isset($_GET['home']) && $_GET['home'] == $team['id']) ? 'selected' : ''; ?>>
                                        <?php echo $team['name']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        
                        <div class="form-group col-md-6">
                            <label for="away" class="form-label">Away Team</label>
                            <select name="away" id="away" class="form-control" required>
                                <option value="">Select Away Team</option>
                                <?php foreach ($teams as $team): ?>
                                    <option value="<?php echo $team['id']; ?>" <?php echo (isset($_GET['away']) && $_GET['away'] == $team['id']) ? 'selected' : ''; ?>>
                                        <?php echo $team['name']; ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                    
                    <div class="form-group">
                        <button type="submit" class="btn btn-primary btn-block">Analyze Match</button>
                    </div>
                </form>
            </div>
        </div>
    </section>
    
    <?php if ($analysis && $homeTeam && $awayTeam): ?>
    <section class="analysis-section">
        <h2 class="match-title">
            <?php echo $homeTeam['name']; ?> vs <?php echo $awayTeam['name']; ?>
        </h2>
        
        <!-- Team Comparison Section -->
        <div class="card mobile-card">
            <div class="card-header collapsible-header" data-target="team-comparison">
                Team Comparison <i class="toggle-icon"></i>
            </div>
            <div class="card-body collapsible-content" id="team-comparison">
                <h4>Recent Form</h4>
                <div class="team-form">
                    <div class="team-form-row">
                        <strong><?php echo $homeTeam['name']; ?>:</strong> 
                        <div class="form-badges">
                            <?php if (!empty($analysis['homeTeam']['stats']['form'])): ?>
                                <?php foreach ($analysis['homeTeam']['stats']['form'] as $result): ?>
                                    <span class="form-badge form-<?php echo $result; ?>"><?php echo $result; ?></span>
                                <?php endforeach; ?>
                            <?php else: ?>
                                No recent form data
                            <?php endif; ?>
                        </div>
                    </div>
                    
                    <div class="team-form-row">
                        <strong><?php echo $awayTeam['name']; ?>:</strong> 
                        <div class="form-badges">
                            <?php if (!empty($analysis['awayTeam']['stats']['form'])): ?>
                                <?php foreach ($analysis['awayTeam']['stats']['form'] as $result): ?>
                                    <span class="form-badge form-<?php echo $result; ?>"><?php echo $result; ?></span>
                                <?php endforeach; ?>
                            <?php else: ?>
                                No recent form data
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                
                <h4 class="mt-4">Key Statistics</h4>
                <div class="table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th>Statistic</th>
                                <th><?php echo $homeTeam['name']; ?></th>
                                <th><?php echo $awayTeam['name']; ?></th>
                            </tr>
                        </thead>
                        <tbody>
                            <tr>
                                <td>Win Rate</td>
                                <td><?php echo isset($analysis['homeTeam']['stats']['winRate']) ? formatPercent($analysis['homeTeam']['stats']['winRate']) : 'N/A'; ?></td>
                                <td><?php echo isset($analysis['awayTeam']['stats']['winRate']) ? formatPercent($analysis['awayTeam']['stats']['winRate']) : 'N/A'; ?></td>
                            </tr>
                            <tr>
                                <td>Avg. Goals Scored</td>
                                <td><?php echo isset($analysis['homeTeam']['stats']['avgGoalsFor']) ? number_format($analysis['homeTeam']['stats']['avgGoalsFor'], 2) : 'N/A'; ?></td>
                                <td><?php echo isset($analysis['awayTeam']['stats']['avgGoalsFor']) ? number_format($analysis['awayTeam']['stats']['avgGoalsFor'], 2) : 'N/A'; ?></td>
                            </tr>
                            <tr>
                                <td>Avg. Goals Conceded</td>
                                <td><?php echo isset($analysis['homeTeam']['stats']['avgGoalsAgainst']) ? number_format($analysis['homeTeam']['stats']['avgGoalsAgainst'], 2) : 'N/A'; ?></td>
                                <td><?php echo isset($analysis['awayTeam']['stats']['avgGoalsAgainst']) ? number_format($analysis['awayTeam']['stats']['avgGoalsAgainst'], 2) : 'N/A'; ?></td>
                            </tr>
                            <tr>
                                <td>Clean Sheet Rate</td>
                                <td><?php echo isset($analysis['homeTeam']['stats']['cleanSheetRate']) ? formatPercent($analysis['homeTeam']['stats']['cleanSheetRate']) : 'N/A'; ?></td>
                                <td><?php echo isset($analysis['awayTeam']['stats']['cleanSheetRate']) ? formatPercent($analysis['awayTeam']['stats']['cleanSheetRate']) : 'N/A'; ?></td>
                            </tr>
                            <tr>
                                <td>BTTS Rate</td>
                                <td><?php echo isset($analysis['homeTeam']['stats']['bttsRate']) ? formatPercent($analysis['homeTeam']['stats']['bttsRate']) : 'N/A'; ?></td>
                                <td><?php echo isset($analysis['awayTeam']['stats']['bttsRate']) ? formatPercent($analysis['awayTeam']['stats']['bttsRate']) : 'N/A'; ?></td>
                            </tr>
                            <tr>
                                <td>Over 2.5 Goals Rate</td>
                                <td><?php echo isset($analysis['homeTeam']['stats']['over2_5Rate']) ? formatPercent($analysis['homeTeam']['stats']['over2_5Rate']) : 'N/A'; ?></td>
                                <td><?php echo isset($analysis['awayTeam']['stats']['over2_5Rate']) ? formatPercent($analysis['awayTeam']['stats']['over2_5Rate']) : 'N/A'; ?></td>
                            </tr>
                            <tr>
                                <td>Over 1.5 Goals Rate</td>
                                <td><?php echo isset($analysis['homeTeam']['stats']['over1_5Rate']) ? formatPercent($analysis['homeTeam']['stats']['over1_5Rate']) : 'N/A'; ?></td>
                                <td><?php echo isset($analysis['awayTeam']['stats']['over1_5Rate']) ? formatPercent($analysis['awayTeam']['stats']['over1_5Rate']) : 'N/A'; ?></td>
                            </tr>
                            <tr>
                                <td>Avg. Corners</td>
                                <td><?php echo isset($analysis['homeTeam']['stats']['avgCornersFor']) ? number_format($analysis['homeTeam']['stats']['avgCornersFor'], 1) : 'N/A'; ?></td>
                                <td><?php echo isset($analysis['awayTeam']['stats']['avgCornersFor']) ? number_format($analysis['awayTeam']['stats']['avgCornersFor'], 1) : 'N/A'; ?></td>
                            </tr>
                        </tbody>
                    </table>
                </div>
                
                <!-- Goal Distribution -->
                <div class="accordion-wrapper mt-4">
                    <div class="accordion-header" data-target="home-goals">
                        <h4>Home Team Goal Distribution <i class="toggle-icon"></i></h4>
                    </div>
                    <div class="accordion-content" id="home-goals">
                        <div class="table-responsive">
                            <table class="table">
                                <thead>
                                    <tr>
                                        <th>Goals Scored</th>
                                        <th>Frequency</th>
                                        <th>Percentage</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (isset($analysis['homeTeam']['stats']['goalDistribution'])): ?>
                                        <?php foreach ($analysis['homeTeam']['stats']['goalDistribution'] as $goals => $data): ?>
                                            <tr>
                                                <td><?php echo $goals; ?></td>
                                                <td><?php echo $data['count']; ?></td>
                                                <td><?php echo formatPercent($data['percentage']); ?></td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php else: ?>
                                        <tr><td colspan="3">No data available</td></tr>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                    
                    <div class="accordion-header" data-target="away-goals">
                        <h4>Away Team Goal Distribution <i class="toggle-icon"></i></h4>
                    </div>
                    <div class="accordion-content" id="away-goals">
                        <div class="table-responsive">
                            <table class="table">
                                <thead>
                                    <tr>
                                        <th>Goals Scored</th>
                                        <th>Frequency</th>
                                        <th>Percentage</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (isset($analysis['awayTeam']['stats']['goalDistribution'])): ?>
                                        <?php foreach ($analysis['awayTeam']['stats']['goalDistribution'] as $goals => $data): ?>
                                            <tr>
                                                <td><?php echo $goals; ?></td>
                                                <td><?php echo $data['count']; ?></td>
                                                <td><?php echo formatPercent($data['percentage']); ?></td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php else: ?>
                                        <tr><td colspan="3">No data available</td></tr>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        
        <!-- Head-to-Head Analysis -->
        <?php if (!empty($analysis['headToHead']['matches'])): ?>
        <div class="card mobile-card">
            <div class="card-header collapsible-header" data-target="head-to-head">
                Head-to-Head History <i class="toggle-icon"></i>
            </div>
            <div class="card-body collapsible-content" id="head-to-head">
                <div class="h2h-summary">
                    <p>
                        <strong>Summary:</strong> 
                        <?php echo $homeTeam['name']; ?> 
                        <strong><?php echo $analysis['headToHead']['homeTeamWins']; ?></strong> wins, 
                        <strong><?php echo $analysis['headToHead']['draws']; ?></strong> draws, 
                        <?php echo $awayTeam['name']; ?> 
                        <strong><?php echo $analysis['headToHead']['awayTeamWins']; ?></strong> wins.
                    </p>
                    <p>
                        Average goals per match: <strong><?php echo number_format($analysis['headToHead']['avgGoalsPerMatch'], 2); ?></strong>
                    </p>
                    
                    <?php if (isset($analysis['headToHead']['homeTeamScoredFirstRate'])): ?>
                    <p>
                        <strong>First to Score:</strong> 
                        <?php echo $homeTeam['name']; ?> scored first in 
                        <strong><?php echo formatPercent($analysis['headToHead']['homeTeamScoredFirstRate']); ?></strong> of matches.
                    </p>
                    <?php endif; ?>
                    
                    <?php if (isset($analysis['headToHead']['avgCornersPerMatch'])): ?>
                    <p>
                        <strong>Corners:</strong> 
                        Average of <strong><?php echo number_format($analysis['headToHead']['avgCornersPerMatch'], 1); ?></strong> corners per match.
                    </p>
                    <?php endif; ?>
                </div>
                
                <div class="table-responsive">
                    <table class="table table-striped">
                        <thead>
                            <tr>
                                <th>Date</th>
                                <th>Home Team</th>
                                <th>Score</th>
                                <th>Away Team</th>
                                <th>Result</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($analysis['headToHead']['matches'] as $match): ?>
                            <tr>
                                <td><?php echo formatDate($match['date'], 'M d, Y'); ?></td>
                                <td><?php echo $match['homeTeamId'] == $homeTeam['id'] ? $homeTeam['name'] : $awayTeam['name']; ?></td>
                                <td><strong><?php echo $match['homeGoals'] . ' - ' . $match['awayGoals']; ?></strong></td>
                                <td><?php echo $match['awayTeamId'] == $homeTeam['id'] ? $homeTeam['name'] : $awayTeam['name']; ?></td>
                                <td>
                                    <?php 
                                    if ($match['winner'] == 'draw') {
                                        echo 'Draw';
                                    } elseif ($match['winner'] == $homeTeam['id']) {
                                        echo $homeTeam['name'] . ' Win';
                                    } else {
                                        echo $awayTeam['name'] . ' Win';
                                    }
                                    ?>
                                </td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>
        <?php endif; ?>
        
        <!-- Safest Bets Section -->
        <div class="card mobile-card safe-bets-card">
            <div class="card-header collapsible-header" data-target="safe-bets">
                Safest Betting Options <i class="toggle-icon"></i>
            </div>
            <div class="card-body collapsible-content" id="safe-bets">
                <?php if (!empty($analysis['recommendations']['safeBets'])): ?>
                    <div class="safe-bets-content">
                        <p class="lead">Based on our analysis, these are the safest betting options for this match:</p>
                        <div class="safe-bets-grid">
                            <?php foreach ($analysis['recommendations']['safeBets'] as $bet): ?>
                            <div class="safe-bet-card">
                                <div class="card-header"><?php echo $bet['type']; ?></div>
                                <div class="card-body">
                                    <h5 class="card-title"><?php echo $bet['bet']; ?></h5>
                                    <p>Probability: <strong><?php echo formatPercent($bet['probability']); ?></strong></p>
                                    
                                    <?php if (isset($analysis['recommendations']['reasoning'][$bet['type']])): ?>
                                    <div class="reasoning">
                                        <h6>Why we recommend this bet:</h6>
                                        <ul>
                                            <?php 
                                            $reasoningKey = strtolower(str_replace(['/', ' '], ['_', '_'], $bet['type']));
                                            $reasons = [];
                                            
                                            // Handle special cases for team goals
                                            if ($bet['type'] == 'Home Team Goals') {
                                                $reasons = $analysis['recommendations']['reasoning']['teamGoals']['home'] ?? [];
                                            }
                                            else if ($bet['type'] == 'Away Team Goals') {
                                                $reasons = $analysis['recommendations']['reasoning']['teamGoals']['away'] ?? [];
                                            }
                                            else {
                                                // Try to find matching reasoning key
                                                foreach ($analysis['recommendations']['reasoning'] as $key => $value) {
                                                    if (stripos($bet['type'], $key) !== false) {
                                                        $reasons = $value;
                                                        break;
                                                    }
                                                }
                                            }
                                            
                                            if (!empty($reasons)):
                                                foreach ($reasons as $reason): 
                                            ?>
                                                <li><?php echo $reason; ?></li>
                                            <?php 
                                                endforeach;
                                            else:
                                            ?>
                                                <li>High statistical probability based on team performance data</li>
                                            <?php endif; ?>
                                        </ul>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                <?php else: ?>
                    <p>No high-confidence bets identified for this match. Consider waiting for better opportunities.</p>
                <?php endif; ?>
            </div>
        </div>
        
        <!-- Betting Recommendations Mobile Tabs -->
        <div class="card mobile-card">
            <div class="card-header">Detailed Betting Analysis</div>
            <div class="card-body">
                <div class="mobile-tabs">
                    <div class="tab-nav">
                        <button class="tab-btn active" data-tab="match-outcome">Match Result</button>
                        <button class="tab-btn" data-tab="goals">Goals Markets</button>
                        <button class="tab-btn" data-tab="team-goals">Team Goals</button>
                        <button class="tab-btn" data-tab="corners">Corners</button>
                        <button class="tab-btn" data-tab="first-to-score">First To Score</button>
                    </div>
                    
                    <div class="tab-content">
                        <!-- Match Outcome Tab -->
                        <div class="tab-pane active" id="match-outcome-tab">
                            <h4>Match Outcome Analysis</h4>
                            <div class="recommendation-content">
                                <h5>Recommended Bet: <span class="confidence-<?php echo strtolower($analysis['recommendations']['matchOutcome']['confidence']); ?>"><?php echo $analysis['recommendations']['matchOutcome']['suggested']; ?></span></h5>
                                <p>Confidence: <strong><?php echo $analysis['recommendations']['matchOutcome']['confidence']; ?></strong></p>
                                
                                <div class="probability-bars">
                                    <p>Home Win (<?php echo formatPercent($analysis['recommendations']['matchOutcome']['homeWin']); ?>)</p>
                                    <div class="progress-container">
                                        <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['matchOutcome']['homeWin']; ?>%">
                                            <?php echo formatPercent($analysis['recommendations']['matchOutcome']['homeWin']); ?>
                                        </div>
                                    </div>
                                    
                                    <p>Draw (<?php echo formatPercent($analysis['recommendations']['matchOutcome']['draw']); ?>)</p>
                                    <div class="progress-container">
                                        <div class="progress-bar progress-bar-warning" style="width: <?php echo $analysis['recommendations']['matchOutcome']['draw']; ?>%">
                                            <?php echo formatPercent($analysis['recommendations']['matchOutcome']['draw']); ?>
                                        </div>
                                    </div>
                                    
                                    <p>Away Win (<?php echo formatPercent($analysis['recommendations']['matchOutcome']['awayWin']); ?>)</p>
                                    <div class="progress-container">
                                        <div class="progress-bar progress-bar-danger" style="width: <?php echo $analysis['recommendations']['matchOutcome']['awayWin']; ?>%">
                                            <?php echo formatPercent($analysis['recommendations']['matchOutcome']['awayWin']); ?>
                                        </div>
                                    </div>
                                </div>
                                
                                <?php if (!empty($analysis['recommendations']['reasoning']['matchOutcome'])): ?>
                                <div class="reasoning-box">
                                    <h5>Analysis Reasoning</h5>
                                    <ul>
                                        <?php foreach ($analysis['recommendations']['reasoning']['matchOutcome'] as $reason): ?>
                                        <li><?php echo $reason; ?></li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                                <?php endif; ?>
                            </div>
                        </div>
                        
                        <!-- Goals Markets Tab -->
                        <div class="tab-pane" id="goals-tab">
                            <!-- Both Teams to Score -->
                            <div class="betting-card">
                                <h4>Both Teams to Score</h4>
                                <div class="recommendation-content">
                                    <h5>Recommended Bet: <span class="confidence-<?php echo strtolower($analysis['recommendations']['btts']['confidence']); ?>"><?php echo $analysis['recommendations']['btts']['suggested']; ?></span></h5>
                                    <p>Confidence: <strong><?php echo $analysis['recommendations']['btts']['confidence']; ?></strong></p>
                                    
                                    <div class="probability-bars">
                                        <p>Yes (<?php echo formatPercent($analysis['recommendations']['btts']['yes']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-success" style="width: <?php echo $analysis['recommendations']['btts']['yes']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['btts']['yes']); ?>
                                            </div>
                                        </div>
                                        
                                        <p>No (<?php echo formatPercent($analysis['recommendations']['btts']['no']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-danger" style="width: <?php echo $analysis['recommendations']['btts']['no']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['btts']['no']); ?>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <?php if (!empty($analysis['recommendations']['reasoning']['btts'])): ?>
                                    <div class="reasoning-box">
                                        <h6>Analysis Reasoning</h6>
                                        <ul>
                                            <?php foreach ($analysis['recommendations']['reasoning']['btts'] as $reason): ?>
                                            <li><?php echo $reason; ?></li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                            
                            <!-- Over/Under 2.5 Goals -->
                            <div class="betting-card">
                                <h4>Over/Under 2.5 Goals</h4>
                                <div class="recommendation-content">
                                    <h5>Recommended Bet: <span class="confidence-<?php echo strtolower($analysis['recommendations']['over_under']['confidence']); ?>"><?php echo $analysis['recommendations']['over_under']['suggested']; ?></span></h5>
                                    <p>Confidence: <strong><?php echo $analysis['recommendations']['over_under']['confidence']; ?></strong></p>
                                    
                                    <div class="probability-bars">
                                        <p>Over 2.5 (<?php echo formatPercent($analysis['recommendations']['over_under']['over2_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-success" style="width: <?php echo $analysis['recommendations']['over_under']['over2_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['over_under']['over2_5']); ?>
                                            </div>
                                        </div>
                                        
                                        <p>Under 2.5 (<?php echo formatPercent($analysis['recommendations']['over_under']['under2_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-secondary" style="width: <?php echo $analysis['recommendations']['over_under']['under2_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['over_under']['under2_5']); ?>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <?php if (!empty($analysis['recommendations']['reasoning']['over_under'])): ?>
                                    <div class="reasoning-box">
                                        <h6>Analysis Reasoning</h6>
                                        <ul>
                                            <?php foreach ($analysis['recommendations']['reasoning']['over_under'] as $reason): ?>
                                            <li><?php echo $reason; ?></li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                            
                            <!-- Over/Under 1.5 Goals -->
                            <div class="betting-card">
                                <h4>Over/Under 1.5 Goals</h4>
                                <div class="recommendation-content">
                                    <h5>Recommended Bet: <span class="confidence-<?php echo strtolower($analysis['recommendations']['over1_5']['confidence']); ?>"><?php echo $analysis['recommendations']['over1_5']['suggested']; ?></span></h5>
                                    <p>Confidence: <strong><?php echo $analysis['recommendations']['over1_5']['confidence']; ?></strong></p>
                                    
                                    <div class="probability-bars">
                                        <p>Over 1.5 (<?php echo formatPercent($analysis['recommendations']['over1_5']['over1_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-success" style="width: <?php echo $analysis['recommendations']['over1_5']['over1_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['over1_5']['over1_5']); ?>
                                            </div>
                                        </div>
                                        
                                        <p>Under 1.5 (<?php echo formatPercent($analysis['recommendations']['over1_5']['under1_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-secondary" style="width: <?php echo $analysis['recommendations']['over1_5']['under1_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['over1_5']['under1_5']); ?>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <?php if (!empty($analysis['recommendations']['reasoning']['over1_5'])): ?>
                                    <div class="reasoning-box">
                                        <h6>Analysis Reasoning</h6>
                                        <ul>
                                            <?php foreach ($analysis['recommendations']['reasoning']['over1_5'] as $reason): ?>
                                            <li><?php echo $reason; ?></li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        
                        <!-- Team Goals Tab -->
                        <div class="tab-pane" id="team-goals-tab">
                            <!-- Home Team Goals -->
                            <div class="betting-card">
                                <h4><?php echo $homeTeam['name']; ?> Goals</h4>
                                <div class="recommendation-content">
                                    <h5>Expected Goals: <strong><?php echo number_format($analysis['recommendations']['teamGoals']['home']['expectedGoals'], 2); ?></strong></h5>
                                    <h5>Most Likely: <strong><?php echo $analysis['recommendations']['teamGoals']['home']['mostLikelyCount']; ?> goals</strong></h5>
                                    <h5>Recommended Bet: <span class="confidence-<?php echo strtolower($analysis['recommendations']['teamGoals']['home']['confidence']); ?>"><?php echo $analysis['recommendations']['teamGoals']['home']['suggested']; ?></span></h5>
                                    
                                    <div class="probability-bars mt-3">
                                        <p>Over 0.5 (<?php echo formatPercent($analysis['recommendations']['teamGoals']['home']['over0_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['teamGoals']['home']['over0_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['teamGoals']['home']['over0_5']); ?>
                                            </div>
                                        </div>
                                        
                                        <p>Over 1.5 (<?php echo formatPercent($analysis['recommendations']['teamGoals']['home']['over1_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['teamGoals']['home']['over1_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['teamGoals']['home']['over1_5']); ?>
                                            </div>
                                        </div>
                                        
                                        <p>Over 2.5 (<?php echo formatPercent($analysis['recommendations']['teamGoals']['home']['over2_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['teamGoals']['home']['over2_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['teamGoals']['home']['over2_5']); ?>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <?php if (!empty($analysis['recommendations']['reasoning']['teamGoals']['home'])): ?>
                                    <div class="reasoning-box">
                                        <h6>Analysis Reasoning</h6>
                                        <ul>
                                            <?php foreach ($analysis['recommendations']['reasoning']['teamGoals']['home'] as $reason): ?>
                                            <li><?php echo $reason; ?></li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                            
                            <!-- Away Team Goals -->
                            <div class="betting-card">
                                <h4><?php echo $awayTeam['name']; ?> Goals</h4>
                                <div class="recommendation-content">
                                    <h5>Expected Goals: <strong><?php echo number_format($analysis['recommendations']['teamGoals']['away']['expectedGoals'], 2); ?></strong></h5>
                                    <h5>Most Likely: <strong><?php echo $analysis['recommendations']['teamGoals']['away']['mostLikelyCount']; ?> goals</strong></h5>
                                    <h5>Recommended Bet: <span class="confidence-<?php echo strtolower($analysis['recommendations']['teamGoals']['away']['confidence']); ?>"><?php echo $analysis['recommendations']['teamGoals']['away']['suggested']; ?></span></h5>
                                    
                                    <div class="probability-bars mt-3">
                                        <p>Over 0.5 (<?php echo formatPercent($analysis['recommendations']['teamGoals']['away']['over0_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['teamGoals']['away']['over0_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['teamGoals']['away']['over0_5']); ?>
                                            </div>
                                        </div>
                                        
                                        <p>Over 1.5 (<?php echo formatPercent($analysis['recommendations']['teamGoals']['away']['over1_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['teamGoals']['away']['over1_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['teamGoals']['away']['over1_5']); ?>
                                            </div>
                                        </div>
                                        
                                        <p>Over 2.5 (<?php echo formatPercent($analysis['recommendations']['teamGoals']['away']['over2_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['teamGoals']['away']['over2_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['teamGoals']['away']['over2_5']); ?>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <?php if (!empty($analysis['recommendations']['reasoning']['teamGoals']['away'])): ?>
                                    <div class="reasoning-box">
                                        <h6>Analysis Reasoning</h6>
                                        <ul>
                                            <?php foreach ($analysis['recommendations']['reasoning']['teamGoals']['away'] as $reason): ?>
                                            <li><?php echo $reason; ?></li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        
                        <!-- Corners Tab -->
                        <div class="tab-pane" id="corners-tab">
                            <div class="betting-card">
                                <h4>Corner Market Analysis</h4>
                                <div class="recommendation-content">
                                    <h5>Expected Corners: <strong><?php echo number_format($analysis['recommendations']['corners']['expectedTotal'], 1); ?></strong></h5>
                                    <h5>Recommended Bet: <span class="confidence-<?php echo strtolower($analysis['recommendations']['corners']['confidence']); ?>"><?php echo $analysis['recommendations']['corners']['suggested']; ?></span></h5>
                                    <p>Confidence: <strong><?php echo $analysis['recommendations']['corners']['confidence']; ?></strong></p>
                                    
                                    <div class="probability-bars">
                                        <p>Over 8.5 Corners (<?php echo formatPercent($analysis['recommendations']['corners']['over8_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['corners']['over8_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['corners']['over8_5']); ?>
                                            </div>
                                        </div>
                                        
                                        <p>Over 9.5 Corners (<?php echo formatPercent($analysis['recommendations']['corners']['over9_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['corners']['over9_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['corners']['over9_5']); ?>
                                            </div>
                                        </div>
                                        
                                        <p>Over 10.5 Corners (<?php echo formatPercent($analysis['recommendations']['corners']['over10_5']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['corners']['over10_5']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['corners']['over10_5']); ?>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <?php if (!empty($analysis['recommendations']['reasoning']['corners'])): ?>
                                    <div class="reasoning-box">
                                        <h5>Analysis Reasoning</h5>
                                        <ul>
                                            <?php foreach ($analysis['recommendations']['reasoning']['corners'] as $reason): ?>
                                            <li><?php echo $reason; ?></li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        
                        <!-- First To Score Tab -->
                        <div class="tab-pane" id="first-to-score-tab">
                            <div class="betting-card">
                                <h4>First Team to Score Analysis</h4>
                                <div class="recommendation-content">
                                    <h5>Recommended Bet: <span class="confidence-<?php echo strtolower($analysis['recommendations']['firstToScore']['confidence']); ?>"><?php echo $analysis['recommendations']['firstToScore']['suggested']; ?></span></h5>
                                    <p>Confidence: <strong><?php echo $analysis['recommendations']['firstToScore']['confidence']; ?></strong></p>
                                    
                                    <div class="probability-bars">
                                        <p><?php echo $homeTeam['name']; ?> (<?php echo formatPercent($analysis['recommendations']['firstToScore']['home']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-primary" style="width: <?php echo $analysis['recommendations']['firstToScore']['home']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['firstToScore']['home']); ?>
                                            </div>
                                        </div>
                                        
                                        <p><?php echo $awayTeam['name']; ?> (<?php echo formatPercent($analysis['recommendations']['firstToScore']['away']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-danger" style="width: <?php echo $analysis['recommendations']['firstToScore']['away']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['firstToScore']['away']); ?>
                                            </div>
                                        </div>
                                        
                                        <p>No Goal (<?php echo formatPercent($analysis['recommendations']['firstToScore']['noGoal']); ?>)</p>
                                        <div class="progress-container">
                                            <div class="progress-bar progress-bar-secondary" style="width: <?php echo $analysis['recommendations']['firstToScore']['noGoal']; ?>%">
                                                <?php echo formatPercent($analysis['recommendations']['firstToScore']['noGoal']); ?>
                                            </div>
                                        </div>
                                    </div>
                                    
                                    <?php if (!empty($analysis['recommendations']['reasoning']['firstToScore'])): ?>
                                    <div class="reasoning-box">
                                        <h5>Analysis Reasoning</h5>
                                        <ul>
                                            <?php foreach ($analysis['recommendations']['reasoning']['firstToScore'] as $reason): ?>
                                            <li><?php echo $reason; ?></li>
                                            <?php endforeach; ?>
                                        </ul>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </section>
    <?php endif; ?>
</div>

<?php
// Include footer
include 'includes/footer.php';
?>